(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    188538,       5573]*)
(*NotebookOutlinePosition[    189184,       5595]*)
(*  CellTagsIndexPosition[    189140,       5591]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Methoden der Bioinformatik",
    FontSize->24,
    FontWeight->"Bold"],
  StyleBox[" \n",
    FontSize->12],
  StyleBox["Eine Einf\[UDoubleDot]hrung",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Marc-Thorsten H\[UDoubleDot]tt und Manuel Dehnert",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Springer-Verlag 2006 (ISBN 3-540-25687-3)",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: ",
  "Posterior-Decodierung"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Die Bestimmung der Posteriorwahrscheinlichkeit f\[UDoubleDot]r eine \
gegebene Sequenz des Kasinobeispiels motiviert diesen ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs. Die Posteriorwahrscheinlichkeit basiert auf dem ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "- und ",
  StyleBox["backward",
    FontSlant->"Italic"],
  "-Algorithmus, die wir nun in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " implementieren werden. Die zugeh\[ODoubleDot]rigen Definitionen finden \
sich in den Gleichungen (2.101) bis (2.111). Der Zustandsraum des HMM, der \
Zustandsraum der Sequenz, die \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten und die \
Emissionswahrscheinlichkeiten entsprechen f\[UDoubleDot]r den ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "-Algorithmus den Definitionen aus dem ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs zum Viterbi-Algorithmus. "
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(\(state = {"\<0\>", "\<F\>", "\<U\>"};\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(observation = {1, 2, 3, 4, 5, 6};\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(emission[z1_, z2_] := 
        Switch[z1, \[IndentingNewLine]"\<F\>", 
          N[1/6], \[IndentingNewLine]"\<U\>", 
          If[z2 \[Equal] 6, 0.5, 0.1], \[IndentingNewLine]"\<0\>", 
          0];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(transition[z1_, z2_] := 
        Switch[{z1, z2}, \[IndentingNewLine]{"\<F\>", "\<F\>"}, 
          0.95, \[IndentingNewLine]{"\<F\>", "\<U\>"}, 
          0.05, \[IndentingNewLine]{"\<U\>", "\<U\>"}, 
          0.90, \[IndentingNewLine]{"\<U\>", "\<F\>"}, 
          0.10, \[IndentingNewLine]{"\<0\>", "\<U\>"}, 
          0.5, \[IndentingNewLine]{"\<0\>", "\<F\>"}, 
          0.5, \[IndentingNewLine]{"\<0\>", "\<0\>"}, 
          0.0, \[IndentingNewLine]{"\<U\>", "\<0\>"}, 
          0.0, \[IndentingNewLine]{"\<F\>", "\<0\>"}, 0.0];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell["\<\
Als Beispielsequenz nutzen wir den im vorangegangenen Exkurs erstellten \
Datensatz, der aus drei Teilsequenzen nach dem Schema fair - unfair - fair \
zusammengesetzt ist. \
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(SeedRandom[2]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(seq0a = Table[Random[Integer, {1, 6}], {50}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({5, 5, 3, 6, 1, 4, 4, 5, 3, 3, 5, 5, 6, 6, 1, 5, 1, 1, 6, 1, 2, 5, 3, 
      3, 1, 1, 2, 3, 3, 5, 2, 6, 2, 1, 4, 2, 5, 6, 6, 6, 5, 4, 4, 3, 5, 6, 2, 
      1, 3, 6}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(seq0b = 
      Table[If[Random[] < 0.5, 6, Random[Integer, {1, 5}]], {20}]\)], "Input",\

  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({6, 2, 6, 6, 5, 6, 4, 6, 1, 1, 6, 6, 2, 5, 6, 3, 6, 6, 6, 
      4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(seq0c = Table[Random[Integer, {1, 6}], {50}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({6, 4, 2, 1, 3, 6, 2, 2, 2, 1, 2, 4, 4, 6, 5, 1, 1, 6, 2, 3, 4, 2, 4, 
      5, 1, 1, 1, 6, 4, 4, 2, 5, 1, 2, 2, 4, 5, 3, 5, 5, 4, 3, 4, 3, 2, 1, 2, 
      4, 1, 2}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(label = 
        Flatten[{Table["\<F\>", {50}], Table["\<U\>", {20}], 
            Table["\<F\>", {50}]}];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(seq = Join[seq0a, seq0b, seq0c];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(L = Length[seq]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(120\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Viterbi-Variable wird nun durch die ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "-Variable abgel\[ODoubleDot]st. Die Maximumsabfrage wird durch eine \
Summation ersetzt. Damit ergibt sich der ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "-Algorithmus als"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(forward[z1_, 0, x_] := If[z1 == "\<0\>", 1, 0]\)], "Input"],

Cell[BoxData[
    \(Do[Do[{\(tmpList = 
              Table[forward[state[\([k]\)], i - 1, seq]*
                  transition[state[\([k]\)], state[\([j]\)]], {k, 1, 
                  Length[state]}];\), \[IndentingNewLine]forward[
              state[\([j]\)], i, seq] = 
            emission[state[\([j]\)], 
                seq[\([i]\)]]*\((Plus @@ tmpList)\)}, \[IndentingNewLine]{j, 
          1, Length[state]}], \[IndentingNewLine]{i, 1, L}]\)], "Input"],

Cell[TextData[{
  "Die ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "-Variable kann nun f\[UDoubleDot]r die Zust\[ADoubleDot]nde 1 (\"0\"), 2 (\
\"F\") und 3 (\"U\") f\[UDoubleDot]r jeden Sequenzindex ",
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->12,
    FontSlant->"Italic"],
  " berechnet werden. Einige Beispiele:\n\n",
  StyleBox["Table[forward[state[[k]], i, seq], {k, 1, Length[state]}]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(i = 0;\)\), "\[IndentingNewLine]", 
    \(Table[
      forward[state[\([k]\)], 0, seq], {k, 1, Length[state]}]\)}], "Input"],

Cell[BoxData[
    \({1, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(i = 1;\)\), "\[IndentingNewLine]", 
    \(Table[
      forward[state[\([k]\)], 1, seq], {k, 1, Length[state]}]\)}], "Input"],

Cell[BoxData[
    \({0, 0.08333333333333333`, 0.05`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(i = 2;\)\), "\[IndentingNewLine]", 
    \(Table[
      forward[state[\([k]\)], 2, seq], {k, 1, Length[state]}]\)}], "Input"],

Cell[BoxData[
    \({0, 0.014027777777777778`, 0.004916666666666667`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Als Terminierung (",
  StyleBox["i = L",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  ") hat man"
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmpList = 
      Table[forward[state[\([k]\)], L, seq], {k, 1, 
          Length[state]}]\)], "Input"],

Cell[BoxData[
    \({0, 4.832893622659731`*^-93, 3.475343979826241`*^-94}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Gesamtwahrscheinlichkeit f\[UDoubleDot]r die Sequenz ergibt sich durch \
die Summation der ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "-Variablen zum Sequenzindex ",
  StyleBox["i = L",
    FontSlant->"Italic"],
  ", multipliziert mit der \[CapitalUDoubleDot]bergangswahrscheinlichkeit in \
den Endzustand \"0\"."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(probSeqForward = Plus @@ tmpList*0.5\)], "Input"],

Cell[BoxData[
    \(2.5902140103211777`*^-93\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Der \[CapitalUDoubleDot]bergang aus den Zust\[ADoubleDot]nden \"F\" und \
\"U\" in einen Endzustand wird in der von uns definierten Funktion der \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten nicht \
ber\[UDoubleDot]cksichtigt. Daher setzen wir die \
entsprechendeWahrscheinlichkeit von 0.5 explizit ein. \n\nNeben der ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "-Variablen ben\[ODoubleDot]tigen wir f\[UDoubleDot]r die \
Posterior-Decodierung die ",
  StyleBox["backward",
    FontSlant->"Italic"],
  "-Variable. Der ",
  StyleBox["backward",
    FontSlant->"Italic"],
  "-Algorithmus unterscheidet sich vom ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "-Algorithmus und vom Viterbi-Algorithmus, wie wir gesehen haben, vor allem \
dadurch, dass er am Ende der Sequenz startet. Deshalb ist es \
n\[ODoubleDot]tig, eine auf diese Situation angepasste Funktion der \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten anzugeben, \
w\[ADoubleDot]hrend der Zustandsraum des HMM, der Zustandsraum der Sequenz \
und die Emissionswahrscheinlichkeiten beibehalten werden. Die \
Wahrscheinlichkeit, vom Endzustand \"0\" in den Zustand \"F\" oder \"U\" \
\[UDoubleDot]berzugehen wird wieder jeweils als 0.5 definiert."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(transitionII[z1_, z2_] := 
      Switch[{z1, z2}, \[IndentingNewLine]{"\<F\>", "\<F\>"}, 
        0.95, \[IndentingNewLine]{"\<F\>", "\<U\>"}, 
        0.05, \[IndentingNewLine]{"\<U\>", "\<U\>"}, 
        0.90, \[IndentingNewLine]{"\<U\>", "\<F\>"}, 
        0.10, \[IndentingNewLine]{"\<0\>", "\<U\>"}, 
        0.0, \[IndentingNewLine]{"\<0\>", "\<F\>"}, 
        0.0, \[IndentingNewLine]{"\<0\>", "\<0\>"}, 
        0.0, \[IndentingNewLine]{"\<U\>", "\<0\>"}, 
        0.5, \[IndentingNewLine]{"\<F\>", "\<0\>"}, 0.5]\)], "Input"],

Cell[TextData[{
  "Der ",
  StyleBox["backward",
    FontSlant->"Italic"],
  "-Algorithmus kann nun wie folgt implementiert werden:"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(backward[z1_, L, x_] := transitionII[z1, "\<0\>"]\)], "Input"],

Cell[BoxData[
    \(Do[Do[{\(tmpList = 
              Table[backward[state[\([j]\)], i + 1, seq]*
                  emission[state[\([j]\)], seq[\([i + 1]\)]]*
                  transition[state[\([k]\)], state[\([j]\)]], {j, 1, 
                  Length[state]}];\), \[IndentingNewLine]backward[
              state[\([k]\)], i, seq] = 
            Plus @@ tmpList}, \[IndentingNewLine]{k, 1, 
          Length[state]}], \[IndentingNewLine]{i, L - 1, 
        1, \(-1\)}]\)], "Input"],

Cell[TextData[{
  "Man erkennt an der Festlegung des Laufindex der \[ADoubleDot]u\[SZ]eren ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife, dass die Iteration nun r\[UDoubleDot]ckw\[ADoubleDot]rts \
erfolgt. Die Terminierung besch\[ADoubleDot]ftigt sich daher mit der \
Indexposition ",
  StyleBox["i = 1",
    FontSlant->"Italic"],
  ". Die Werte der ",
  StyleBox["backward",
    FontSlant->"Italic"],
  "-Variablen an dieser Stelle lassen sich in der \[UDoubleDot]blichenWeise \
abfragen:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmpList = 
      Table[backward[state[\([k]\)], 1, seq], {k, 1, 
          Length[state]}]\)], "Input"],

Cell[BoxData[
    \({1.7149184475600924`*^-92, 2.4957483681799397`*^-92, 
      1.0208474070091166`*^-92}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Summation \[UDoubleDot]ber die (mit den entsprechenden \
\[CapitalUDoubleDot]bergangs- und Emissionswahrscheinlichkeiten versehenen) \
",
  StyleBox["backward",
    FontSlant->"Italic"],
  "-Variablen bei ",
  StyleBox["i = 1",
    FontSlant->"Italic"],
  " ist ein alternativer Weg zur Gesamtwahrscheinlichkeit ",
  StyleBox["P(x)",
    FontSlant->"Italic"],
  " der Sequenz ",
  StyleBox["x",
    FontSlant->"Italic"],
  "."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(probSeqBackward = 
      Plus @@ Table[
          transition["\<0\>", state[\([k]\)]]*
            emission[state[\([k]\)], seq[\([1]\)]]*
            backward[state[\([k]\)], 1, seq], {k, 1, 
            Length[state]}]\)], "Input"],

Cell[BoxData[
    \(2.5902140103211747`*^-93\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die f\[UDoubleDot]r unsere Sequenz durch den ",
  StyleBox["backward",
    FontSlant->"Italic"],
  "-Algorithmus berechnete Gesamtwahrscheinlichkeit ist mit dem durch den ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "-Algorithmus bestimmten Wert identisch. Diese \
\[CapitalUDoubleDot]bereinstimmung ist eine gute \
Konsistenzpr\[UDoubleDot]fung der Implementierung. Die \
Posteriorwahrscheinlichkeit entlang einer Sequenz kann nun durch Zusammenf\
\[UDoubleDot]gen der oben definierten ",
  StyleBox["forward",
    FontSlant->"Italic"],
  "- und ",
  StyleBox["backward",
    FontSlant->"Italic"],
  "-Algorithmen berechnet werden."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(Do[\[IndentingNewLine]postDec[state[\([k]\)], i, 
          seq] = \((forward[state[\([k]\)], i, seq]*
              backward[state[\([k]\)], i, seq])\)/
          probSeqBackward, \[IndentingNewLine]{k, 1, 
        Length[state]}, \[IndentingNewLine]{i, 1, L}]\)], "Input"],

Cell["\<\
Die Wahrscheinlichkeit f\[UDoubleDot]r einen fairen W\[UDoubleDot]rfel wird \
auf diese Weise entlang der Sequenz protokolliert:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(postTable = Table[postDec["\<F\>", i, seq], {i, 1, L}];\)\)], "Input"],

Cell[TextData[{
  "Die folgenden ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Befehle dienen der Visualisierung des Ergebnisses. Abbildung 2.41 zeigt \
die Posteriorwahrscheinlichkeit f\[UDoubleDot]r das Vorliegen eines fairen W\
\[UDoubleDot]rfels entlang der Abfolge von W\[UDoubleDot]rfelereignissen. Die \
grau hinterlegte Fl\[ADoubleDot]che markiert die Teilsequenz, der ein \
unfairer W\[UDoubleDot]rfel zugrunde liegt."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(label1 = 
        label /. {"\<F\>" \[Rule] 0, "\<U\>" \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(plpost = 
        ListPlot[postTable, PlotJoined \[Rule] True, Frame \[Rule] True, 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(coord1 = 
        Flatten[Position[Abs[label1 - RotateLeft[label1, 1]], 
            1]];\)\)], "Input"],

Cell[BoxData[
    \(\(rectangleList = 
        Map[{GrayLevel[0.9], Rectangle[{#[\([1]\)], 0}, {#[\([2]\)], 1}]} &, 
          Partition[coord1, 2]];\)\)], "Input"],

Cell[BoxData[
    \(\(plrectangle = 
        Show[Graphics[rectangleList], 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[plpost, plrectangle, plpost, AspectRatio \[Rule] 0.5, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00793651 0.0119048 0.47619 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0119 -6 -4.5 ]
[-0.0125 .0119 0 4.5 ]
[-0.0125 .10714 -18 -4.5 ]
[-0.0125 .10714 0 4.5 ]
[-0.0125 .20238 -18 -4.5 ]
[-0.0125 .20238 0 4.5 ]
[-0.0125 .29762 -18 -4.5 ]
[-0.0125 .29762 0 4.5 ]
[-0.0125 .39286 -18 -4.5 ]
[-0.0125 .39286 0 4.5 ]
[-0.0125 .4881 -6 -4.5 ]
[-0.0125 .4881 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(20)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(40)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(60)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(80)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(100)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(120)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0119 m
.00625 .0119 L
s
[(0)] -0.0125 .0119 1 0 Mshowa
0 .10714 m
.00625 .10714 L
s
[(0.2)] -0.0125 .10714 1 0 Mshowa
0 .20238 m
.00625 .20238 L
s
[(0.4)] -0.0125 .20238 1 0 Mshowa
0 .29762 m
.00625 .29762 L
s
[(0.6)] -0.0125 .29762 1 0 Mshowa
0 .39286 m
.00625 .39286 L
s
[(0.8)] -0.0125 .39286 1 0 Mshowa
0 .4881 m
.00625 .4881 L
s
[(1)] -0.0125 .4881 1 0 Mshowa
.125 Mabswid
0 .03571 m
.00375 .03571 L
s
0 .05952 m
.00375 .05952 L
s
0 .08333 m
.00375 .08333 L
s
0 .13095 m
.00375 .13095 L
s
0 .15476 m
.00375 .15476 L
s
0 .17857 m
.00375 .17857 L
s
0 .22619 m
.00375 .22619 L
s
0 .25 m
.00375 .25 L
s
0 .27381 m
.00375 .27381 L
s
0 .32143 m
.00375 .32143 L
s
0 .34524 m
.00375 .34524 L
s
0 .36905 m
.00375 .36905 L
s
0 .41667 m
.00375 .41667 L
s
0 .44048 m
.00375 .44048 L
s
0 .46429 m
.00375 .46429 L
s
.25 Mabswid
0 0 m
0 .5 L
s
.02381 .49375 m
.02381 .5 L
s
.18254 .49375 m
.18254 .5 L
s
.34127 .49375 m
.34127 .5 L
s
.5 .49375 m
.5 .5 L
s
.65873 .49375 m
.65873 .5 L
s
.81746 .49375 m
.81746 .5 L
s
.97619 .49375 m
.97619 .5 L
s
.125 Mabswid
.06349 .49625 m
.06349 .5 L
s
.10317 .49625 m
.10317 .5 L
s
.14286 .49625 m
.14286 .5 L
s
.22222 .49625 m
.22222 .5 L
s
.2619 .49625 m
.2619 .5 L
s
.30159 .49625 m
.30159 .5 L
s
.38095 .49625 m
.38095 .5 L
s
.42063 .49625 m
.42063 .5 L
s
.46032 .49625 m
.46032 .5 L
s
.53968 .49625 m
.53968 .5 L
s
.57937 .49625 m
.57937 .5 L
s
.61905 .49625 m
.61905 .5 L
s
.69841 .49625 m
.69841 .5 L
s
.7381 .49625 m
.7381 .5 L
s
.77778 .49625 m
.77778 .5 L
s
.85714 .49625 m
.85714 .5 L
s
.89683 .49625 m
.89683 .5 L
s
.93651 .49625 m
.93651 .5 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.99375 .0119 m
1 .0119 L
s
.99375 .10714 m
1 .10714 L
s
.99375 .20238 m
1 .20238 L
s
.99375 .29762 m
1 .29762 L
s
.99375 .39286 m
1 .39286 L
s
.99375 .4881 m
1 .4881 L
s
.125 Mabswid
.99625 .03571 m
1 .03571 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .15476 m
1 .15476 L
s
.99625 .17857 m
1 .17857 L
s
.99625 .22619 m
1 .22619 L
s
.99625 .25 m
1 .25 L
s
.99625 .27381 m
1 .27381 L
s
.99625 .32143 m
1 .32143 L
s
.99625 .34524 m
1 .34524 L
s
.99625 .36905 m
1 .36905 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .44048 m
1 .44048 L
s
.99625 .46429 m
1 .46429 L
s
.25 Mabswid
1 0 m
1 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.03175 .39426 m
.03968 .41151 L
.04762 .41602 L
.05556 .40941 L
.06349 .4381 L
.07143 .45354 L
.07937 .46117 L
.0873 .46369 L
.09524 .46198 L
.10317 .45545 L
.11111 .44179 L
.11905 .41618 L
.12698 .36957 L
.13492 .36751 L
.14286 .4075 L
.15079 .42824 L
.15873 .43707 L
.16667 .4371 L
.1746 .42834 L
.18254 .45114 L
.19048 .46381 L
.19841 .4708 L
.20635 .47461 L
.21429 .47656 L
.22222 .47736 L
.23016 .47727 L
.2381 .47628 L
.24603 .47403 L
.25397 .46972 L
.2619 .46183 L
.26984 .44759 L
.27778 .42194 L
.28571 .42938 L
.29365 .42717 L
.30159 .41454 L
.30952 .38703 L
.31746 .33492 L
.3254 .23982 L
.33333 .21465 L
.34127 .22859 L
.34921 .29872 L
.35714 .33438 L
.36508 .34815 L
.37302 .34492 L
.38095 .32353 L
.38889 .27644 L
.39683 .27584 L
.40476 .25413 L
.4127 .20362 L
.42063 .10649 L
Mistroke
.42857 .07531 L
.43651 .07187 L
.44444 .04849 L
.45238 .04523 L
.46032 .05807 L
.46825 .05378 L
.47619 .06803 L
.48413 .06418 L
.49206 .08184 L
.5 .08007 L
.50794 .05824 L
.51587 .0579 L
.52381 .07862 L
.53175 .07958 L
.53968 .06111 L
.54762 .06373 L
.55556 .04844 L
.56349 .05062 L
.57143 .07295 L
.57937 .14276 L
.5873 .17606 L
.59524 .28621 L
.60317 .34606 L
.61111 .37672 L
.61905 .38904 L
.62698 .38736 L
.63492 .42612 L
.64286 .44732 L
.65079 .45843 L
.65873 .4634 L
.66667 .46396 L
.6746 .46031 L
.68254 .45118 L
.69048 .43333 L
.69841 .44548 L
.70635 .44946 L
.71429 .44668 L
.72222 .43615 L
.73016 .4553 L
.7381 .46588 L
.74603 .47161 L
.75397 .47453 L
.7619 .47568 L
.76984 .47544 L
.77778 .47374 L
.78571 .46998 L
.79365 .46283 L
.80159 .44977 L
.80952 .46318 L
.81746 .47065 L
Mistroke
.8254 .47481 L
.83333 .47712 L
.84127 .47841 L
.84921 .47912 L
.85714 .47952 L
.86508 .47974 L
.87302 .47986 L
.88095 .47992 L
.88889 .47994 L
.89683 .47993 L
.90476 .47989 L
.9127 .4798 L
.92063 .47963 L
.92857 .47931 L
.93651 .47875 L
.94444 .47773 L
.95238 .47591 L
.96032 .47263 L
.96825 .46674 L
.97619 .45615 L
Mfstroke
.9 g
.42063 .0119 m
.42063 .4881 L
.57937 .4881 L
.57937 .0119 L
F
0 g
.03175 .39426 m
.03968 .41151 L
.04762 .41602 L
.05556 .40941 L
.06349 .4381 L
.07143 .45354 L
.07937 .46117 L
.0873 .46369 L
.09524 .46198 L
.10317 .45545 L
.11111 .44179 L
.11905 .41618 L
.12698 .36957 L
.13492 .36751 L
.14286 .4075 L
.15079 .42824 L
.15873 .43707 L
.16667 .4371 L
.1746 .42834 L
.18254 .45114 L
.19048 .46381 L
.19841 .4708 L
.20635 .47461 L
.21429 .47656 L
.22222 .47736 L
.23016 .47727 L
.2381 .47628 L
.24603 .47403 L
.25397 .46972 L
.2619 .46183 L
.26984 .44759 L
.27778 .42194 L
.28571 .42938 L
.29365 .42717 L
.30159 .41454 L
.30952 .38703 L
.31746 .33492 L
.3254 .23982 L
.33333 .21465 L
.34127 .22859 L
.34921 .29872 L
.35714 .33438 L
.36508 .34815 L
.37302 .34492 L
.38095 .32353 L
.38889 .27644 L
.39683 .27584 L
.40476 .25413 L
.4127 .20362 L
.42063 .10649 L
Mistroke
.42857 .07531 L
.43651 .07187 L
.44444 .04849 L
.45238 .04523 L
.46032 .05807 L
.46825 .05378 L
.47619 .06803 L
.48413 .06418 L
.49206 .08184 L
.5 .08007 L
.50794 .05824 L
.51587 .0579 L
.52381 .07862 L
.53175 .07958 L
.53968 .06111 L
.54762 .06373 L
.55556 .04844 L
.56349 .05062 L
.57143 .07295 L
.57937 .14276 L
.5873 .17606 L
.59524 .28621 L
.60317 .34606 L
.61111 .37672 L
.61905 .38904 L
.62698 .38736 L
.63492 .42612 L
.64286 .44732 L
.65079 .45843 L
.65873 .4634 L
.66667 .46396 L
.6746 .46031 L
.68254 .45118 L
.69048 .43333 L
.69841 .44548 L
.70635 .44946 L
.71429 .44668 L
.72222 .43615 L
.73016 .4553 L
.7381 .46588 L
.74603 .47161 L
.75397 .47453 L
.7619 .47568 L
.76984 .47544 L
.77778 .47374 L
.78571 .46998 L
.79365 .46283 L
.80159 .44977 L
.80952 .46318 L
.81746 .47065 L
Mistroke
.8254 .47481 L
.83333 .47712 L
.84127 .47841 L
.84921 .47912 L
.85714 .47952 L
.86508 .47974 L
.87302 .47986 L
.88095 .47992 L
.88889 .47994 L
.89683 .47993 L
.90476 .47989 L
.9127 .4798 L
.92063 .47963 L
.92857 .47931 L
.93651 .47875 L
.94444 .47773 L
.95238 .47591 L
.96032 .47263 L
.96825 .46674 L
.97619 .45615 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`00703oool2000002<0oooo100000030?ooo`8000008P3oool300000080oooo0P00000P0?oo
o`<00000103oool200000240oooo0P0000040?ooo`8000007@3oool500000080oooo0P0000040?oo
o`8000006P3oool5000000030?ooo`0000000000008000000`3oool2000000H0oooo000K0?ooo`04
0000003oool0oooo00000280oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000R
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool07@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000N0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo000000050?ooo`04
0000003oool0oooo000000D0oooo000K0?ooo`040000003oool0oooo000002<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000O0?ooo`D0000000D0oooo0000003oool0oooo0000
000O0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000007`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000001h0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool001/0oooo
00@000000?ooo`3oool00000903oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool07@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001l0oooo0`00
00030?ooo`040000003oool0oooo00000200oooo0P0000030?ooo`040000003oool0oooo000001h0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`006`3oool010000000oooo0?ooo`00000R0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000803oool00`000000oooo000000020?ooo`04
0000003oool0oooo00000200oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000O
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000007P3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0I0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo000L0?ooo`800000903oool2000000@0oooo0P00000R0?ooo`8000000`3oool2
00000240oooo0`0000030?ooo`8000008@3oool2000000@0oooo0P00000N0?ooo`800000103oool2
000000@0oooo0P00000K0?ooo`800000103oool2000000@0oooo0P0000060?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`005`3ooooo000000D000001@3oool00100oooo0P0000050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`003`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`030?ooo`003`3o
ool010000000oooo0?ooo`0000040?ooo`800000o`3oool3000000D0oooo000?0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0JP3ooolY0>KViVd0oooo00<000000?ooo`3oool0
0`3oool000l0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1Z0?ooobT0i^KV
K@3oool00`000000oooo0?ooo`030?ooo`00403oool2000000D0oooo00<000000?ooo`3oool0JP3o
oolY0>KViVd0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0JP3ooolY
0>KViVd0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0JP3ooolY0>KV
iVd0oooo00<000000?ooo`3oool00`3oool001L0oooo0P00001[0?ooobT0i^KVK03oool2000000D0
oooo000G0?ooo`030000003oool0oooo06X0oooo:@3Vi^I]0?ooo`030000003oool0oooo00<0oooo
000G0?ooo`030000003oool0oooo06X0oooo203Vi^H00`000000i^KV0>KViP0N0>KViVd0oooo00<0
00000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0JP3oool60>KViP<000006P3Vi^H0
0`000000i^KV0>KViP030>KViVd0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?oo
o`3oool0JP3oool60>KViP040000003Vi^H0i^KV000001P0i^KV00@000000>KViP00000000000`3V
i^I]0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo06X0oooo1@3Vi^H0
1@000000i^KV0>KViP3Vi^H000000080i^KV00<000000>KViP3Vi^H04`3Vi^H010000000i^KV0>KV
iP0000030>KViVd0oooo00<000000?ooo`3oool00`3oool001L0oooo0P00001[0?ooo`D0i^KV00<0
00000>KViP3Vi^H00P3Vi^H2000000030>KViP000000i^KV00L0i^KV0`0000080>KViP030000003V
i^H0i^KV0080i^KV00<000000>KViP3Vi^H0K03oool2000000D0oooo000G0?ooo`030000003oool0
oooo06X0oooo1@3Vi^H00`000000i^KV0>KViP050>KViP040000003Vi^H0i^KV000000D0i^KV00<0
00000>KViP0000001@3Vi^H4000000@0i^KV00<000000>KViP3Vi^H0K@3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`1Z0?ooo`@0i^KV00<000000>KViP3Vi^H01`3Vi^H3
000000@0i^KV00D000000>KViP3Vi^H0i^KV000000030>KViP030000003Vi^H0i^KV00H0i^KV00<0
00000>KViP3Vi^H0K@3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1Z
0?ooo`@0i^KV00<000000>KViP3Vi^H02P3Vi^H01@000000i^KV0>KViP3Vi^H0000000<0i^KV00D0
00000>KViP3Vi^H0i^KV000000090>KViP030000003Vi^H0oooo06`0oooo00<000000?ooo`3oool0
0`3oool001L0oooo00<000000?ooo`3oool0JP3oool20>KViP8000003@3Vi^H010000000i^KV0>KV
iP0000050>KViP030000003Vi^H0000000X0i^KV00<000000>KViP3oool0K03oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1Z0?ooo`80i^KV00<000000>KViP3Vi^H03@3V
i^H00`000000i^KV000000050>KViP<000002P3Vi^H00`000000i^KV0?ooo`1/0?ooo`030000003o
ool0oooo00<0oooo000G0?ooo`800000J`3oool00`3Vi^H000000>KViP0?0>KViP8000004`3Vi^H0
0`000000i^KV0?ooo`1[0?ooo`8000001@3oool001L0oooo00<000000?ooo`3oool0JP3oool00`3V
i^H000000>KViP0T0>KViP030000003Vi^H0oooo06`0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool0JP3oool00`3Vi^H000000>KViP0T0>KViP030000003Vi^H0oooo06`0
oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0JP3oool00`3Vi^H00000
0>KViP0U0>KViP030000003oool0oooo06/0oooo00<000000?ooo`3oool00`3oool000@0oooo0P00
00040?ooo`8000000`3oool4000000@0oooo00<000000?ooo`3oool0JP3oool00`000000i^KV0>KV
iP0U0>KViP030000003oool0oooo06/0oooo00<000000?ooo`3oool00`3oool000<0oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06X0oooo00<0
00000>KViP3Vi^H09@3Vi^H00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00<0oooo0003
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool2000006/0oooo00<0
00000>KViP3Vi^H09@3Vi^H00`000000oooo0?ooo`1Y0?ooo`<000001@3oool000<0oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06X0oooo00<0
00000>KViP3Vi^H09@3Vi^H00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00<0oooo0003
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1Z0?ooo`030000003Vi^H0i^KV02D0i^KV00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`030?ooo`00103oool2000000X0oooo0P0000050?ooo`030000003oool0oooo06X0oooo00<0
00000>KViP3Vi^H09@3Vi^H00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00<0oooo000G
0?ooo`030000003oool0oooo06X0oooo00<000000>KViP3Vi^H09@3Vi^H00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo06X0oooo00<000000>KV
iP3Vi^H09@3Vi^H00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo06X0oooo00<000000>KViP3Vi^H09P3Vi^H00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo00<0oooo000G0?ooo`800000JP3oool00`000000i^KV0>KViP0W0>KViP030000
003oool0oooo06T0oooo0P0000050?ooo`005`3oool00`000000oooo0?ooo`1Y0?ooo`030000003V
i^H0i^KV02L0i^KV00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`030?ooo`005`3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003Vi^H0i^KV02L0i^KV00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1Y0?ooo`030000003Vi^H0i^KV
02L0i^KV00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`1Y0?ooo`030000003Vi^H0i^KV02L0i^KV00<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1Y0?ooo`030000003Vi^H0i^KV02L0i^KV
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`030?ooo`005`3oool2000006X0oooo00<0
00000>KViP3Vi^H09`3Vi^H00`3oool000000?ooo`1Y0?ooo`8000001@3oool001L0oooo00<00000
0?ooo`3oool0J@3oool00`000000i^KV0>KViP0W0>KViP030?ooo`000000oooo06X0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0J@3oool00`000000i^KV0>KViP0W0>KV
iP030?ooo`000000oooo06X0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3o
ool0J@3oool00`000000i^KV0>KViP0W0>KViP030?ooo`000000oooo06X0oooo00<000000?ooo`3o
ool00`3oool001L0oooo00<000000?ooo`3oool0J@3oool00`000000i^KV0>KViP0W0>KViP80oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?oo
o`1Y0?ooo`030000003Vi^H0i^KV02L0i^KV0P3oool00`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo00<0oooo000G0?ooo`800000J@3oool00`000000oooo0>KViP0X0>KViP80oooo00<00000
0?ooo`3oool0I`3oool2000000D0oooo000G0?ooo`030000003oool0oooo06P0oooo00<000000?oo
o`3Vi^H0:03Vi^H20?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0>KViP0X0>KViP80oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0i^KV02P0i^KV0P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00<0oooo
00040?ooo`800000103oool2000000D0oooo0`0000030?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3Vi^H0:03Vi^H20?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool00`3o
ool000<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3Vi^H0:03Vi^H20?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool00`3oool000<0oooo00@000000?ooo`3oool00000203oool5000000<0oooo0P00
001Y0?ooo`030000003oool0i^KV02P0i^KV0P3oool00`000000oooo0?ooo`1V0?ooo`<000001@3o
ool000<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3Vi^H0:03Vi^H30?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool00`3oool000<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
000000040?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3Vi^H0:03Vi^H30?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool00`3oool000@0oooo0P00000;0?ooo`800000103o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3Vi^H0:03V
i^H30?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00`3oool001L0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02T0i^KV0`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0Y0>KViP<0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`030?ooo`005`3oool2000005<0oooo00<000000?ooo`00
00004P3oool00`000000oooo0?ooo`0Y0>KViP<0oooo00<000000?ooo`3oool0IP3oool2000000D0
oooo000G0?ooo`030000003oool0oooo0580oooo00@000000?ooo`3oool000004@3oool00`000000
oooo0?ooo`0Y0>KViP<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`1B0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool0:@3Vi^H30?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3o
ool0:@3Vi^H30?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool000000100oooo00@000000?ooo`3o
ool0oooo:@3Vi^H30?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool000000100oooo00@000000?oo
o`3oool0oooo:@3Vi^H30?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00`3oool0
01L0oooo0P00001B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool01000
0000oooo0?ooo`3ooolY0>KViP<0oooo00<000000?ooo`3oool0IP3oool2000000D0oooo000G0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?oo
o`040000003oool0oooo0?ooobT0i^KV0`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo00<0oooo000G0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`040000003oool0oooo0?ooobT0i^KV0`3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo:@3Vi^H40?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3ooolY0>KViP@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`020?ooobT0i^KV103oool00`000000oooo0?ooo`1V0?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo:@3Vi^H40?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool00`3oool001L0oooo0P00001A0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0203oool4000000D0oooo:@3Vi^H40?ooo`030000003oool0
oooo06D0oooo0P0000050?ooo`005`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooobT0i^KV103oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo:@3Vi^H40?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3ooolY0>KViP@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`030?ooo`00103oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooobT0i^KV103oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00<0oooo0003
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooobT0i^KV103oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00<0oooo
00030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool200000540
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo:@3Vi^H40?ooo`030000003oool0oooo06@0oooo0`0000050?ooo`000`3oool010000000oooo
0?ooo`0000080?ooo`<000001@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooobT0i^KV1@3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo00<0oooo00030?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooobT0i^KV1@3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo00<0oooo00040?ooo`8000002P3oool3000000@0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0203ooolY0>KViPD0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooobT0i^KV1@3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo:@3Vi^H5
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool00`3oool001L0oooo0P00001@0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?oo
obT0i^KV1@3oool00`000000oooo0?ooo`1T0?ooo`8000001@3oool001L0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0203ooolY0>KViPD0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`090?ooobT0i^KV1@3oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo:@3Vi^H60?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3ooolY
0>KViPH0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`030?ooo`005`3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000303ooolY
0>KViPH0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`030?ooo`005`3oool20000
0500oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000<0?ooobT0i^KV1P3oool0
0`000000oooo0?ooo`1S0?ooo`8000001@3oool001L0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0:0?ooo`8000003@3ooolY0>KViPH0oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01T0
oooo:@3Vi^H60?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0I0?ooobT0i^KV1`3oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool06@3ooolY0>KViPL0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01T0oooo:@3Vi^H7
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool00`3oool001L0oooo0P00000O0?oo
o`<00000;@3oool00`000000oooo0?ooo`0I0?ooobT0i^KV1`3oool00`000000oooo0?ooo`1R0?oo
o`8000001@3oool001L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0000000]0?ooo`03
0000003oool0oooo01T0oooo:@3Vi^H80?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool00`3oool001L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0000000/0?ooo`030000
003oool0oooo01X0oooo:@3Vi^H80?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
0`3oool001L0oooo00<000000?ooo`3oool07@3oool01@000000oooo0?ooo`3oool0000002/0oooo
00<000000?ooo`3oool06P3ooolY0>KViPT0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`030?ooo`00103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`0M0?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`0J0?ooobT0i^KV
2@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00<0oooo00030?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0M0?ooo`05
0000003oool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`0J0?ooobT0i^KV2P3oool30000
0600oooo00<000000?ooo`3oool00`3oool000<0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`8000007P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<0
00000?ooo`3oool06P3ooolY0>KViP`0oooo00<000000?ooo`3oool0G03oool3000000D0oooo0003
0?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool0
6`3ooolY0>KViP`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`030?ooo`000`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0K0?ooobT0i^KV3@3oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo00<0oooo00040?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0K0?ooobT0i^KV3@3oool00`000000oooo0?ooo`1M0?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool06`3o
oolY0>KViPd0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`030?ooo`005`3oool0
0`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0703ooolY0>KViPd0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`08
0?ooo`@00000403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0703ooolY0>KViPd0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`03
0?ooo`005`3oool2000000d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool07@3ooolY0>KViPh0oooo00<000000?oo
o`3oool0F`3oool2000000D0oooo000G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0M0?ooobT0i^KV3P3oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo0P0000020?ooo`030000
003oool0oooo01h0oooo:@3Vi^H>0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
0`3oool001L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo008000008@3ooolY0>KViPh0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01`3oool010000000oooo0?ooo`3oool2000001T0oooo00<000000?ooo`3oool08`3o
oolY0>KViPl0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo00<0oooo000G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`<000000P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02<0oooo:@3Vi^H?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00<0oooo000G0?ooo`8000003P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0S0?ooobT0i^KV403oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo
000000D0oooo0P0000160?ooo`8000001@3oool001L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0T0?ooobT0i^KV403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0T0?oo
obT0i^KV4@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0`0000030?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`030?oo
o`005`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02D0oooo:@3Vi^HA0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`80
0000<`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00@0oooo0P00000D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
9@3ooolY0>KViQ80oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`000000:`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0oooo
0P00000F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09P3ooolY0>KViQ<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo
00@000000?ooo`3oool00000:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo000G0?ooo`8000004`3oool3000001T0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0W0?ooobT0i^KV503oool400000140oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool2000000D0oooo
000G0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0303oool2000002X0oooo:@3V
i^HZ0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool2000002D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00T0oooo0P00000/0?ooobT0i^KV:`3oool3000000D0oooo0P000009
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`005`3oool00`000000oooo0?ooo`0a0?ooo`/00000;P3ooolY0>KViRh0oooo1@00000<0?oo
o`H000006@3oool4000000/0oooo00<000000?ooo`3oool00`3oool000l0oooo1@0000030?ooo`03
0000003oool0oooo06X0oooo:@3Vi^I50?oooaT000003`3oool00`000000oooo0?ooo`030?ooo`00
4@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06X0oooo:@3Vi^I]0?ooo`030000
003oool0oooo00<0oooo000A0?ooo`030000003oool0oooo00<0oooo0P00001[0?ooobT0i^KVJ`3o
ool3000000D0oooo000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo000A0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo000@0?ooo`8000001@3ooooo000000D000001@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-14.3746, -0.124317, 0.487075, \
0.00811793}}]
}, Open  ]],

Cell[TextData[{
  "Abbildung 2.41 ist (bis auf die Achsenbeschriftung und Formatierung) das \
Ergebnis dieses letzten ",
  StyleBox["Show",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehls. Man sieht deutlich, wie die Posteriorwahrscheinlichkeit des \
fairen W\[UDoubleDot]rfels in der \"U\"-Region absinkt. \n\nUm \
fortgeschrittenere, weniger schematische Tests dieser Posterior-Decodierung \
durchf\[UDoubleDot]hren zu k\[ODoubleDot]nnen, werden wir nun ein Programm \
entwerfen und testen, das pr\[ADoubleDot]zise nach dem Modell des \
Kasinobeispiels Zahlen zwischen 1 und 6 emittiert."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(SeedRandom[2]\), "\[IndentingNewLine]", 
    \(makeState[state_] := 
      Module[{x}, \[IndentingNewLine]x = Random[]; \[IndentingNewLine]Switch[
          state, \[IndentingNewLine]"\<F\>", 
          If[x <= 0.95, "\<F\>", "\<U\>"], \[IndentingNewLine]"\<U\>", 
          If[x <= 0.9, "\<U\>", "\<F\>"], \[IndentingNewLine]"\<0\>", 
          If[x <= 0.5, "\<F\>", "\<U\>"]\[IndentingNewLine]]\
\[IndentingNewLine]]\)}], "Input"],

Cell["\<\
Diese Routine gibt ein Symbol unter Verwendung des (als Argument \
eingetragenen) vorangegangenen Symbols aus:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(start = makeState["\<0\>"]\)], "Input"],

Cell[BoxData[
    \("F"\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Mit dem Befehl ",
  StyleBox["NestList",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " kann damit nun eine l\[ADoubleDot]ngere Sequenz erzeugt werden:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(stateSeq = NestList[makeState, start, 299]\)], "Input"],

Cell[BoxData[
    \({"F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "U", "U", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "U", "U", 
      "U", "U", "U", "U", "U", "U", "U", "U", "U", "U", "U", "U", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "U", "U", "U", "U", "U", 
      "U", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "U", "U", "U", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "U", "U", "U", "U", "U", "U", 
      "U", "U", "U", "U", "U", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "U", "U", "U", "U", "U", "U", "U", "U", "U", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "U", "U", "U", "U", "U", "U", 
      "U", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
      "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "U", "U", "U", 
      "F", "F", "F", "F", "F", "U"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Dies liefert zugleich die Referenzsequenz f\[UDoubleDot]r den sp\
\[ADoubleDot]teren Vergleich mit der Posteriorwahrscheinlichkeit. Nun kann \
mit Hilfe der Emissionswahrscheinlichkeiten\ndiese interne Sequenz in eine m\
\[ODoubleDot]gliche, mit den Modellparametern konsistente beobachtete Sequenz \
\[UDoubleDot]berf\[UDoubleDot]hrt werden. Dies geschieht mit einer neuen \
Routine ",
  StyleBox["makeObservation",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[{
    \(SeedRandom[1]\), "\[IndentingNewLine]", 
    \(makeObservation[state_] := 
      Module[{x}, \[IndentingNewLine]x = Random[]; \[IndentingNewLine]Switch[
          state, \[IndentingNewLine]"\<F\>", 
          Random[Integer, {1, 6}], \[IndentingNewLine]"\<U\>", 
          If[x \[LessEqual] 0.5, 6, 
            Random[Integer, {1, 
                5}]]\[IndentingNewLine]]\[IndentingNewLine]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(seq = 
      Table[makeObservation[stateSeq[\([i]\)]], {i, 1, 
          Length[stateSeq]}]\)], "Input"],

Cell[BoxData[
    \({4, 6, 6, 3, 3, 3, 6, 1, 1, 2, 5, 6, 4, 6, 1, 1, 5, 6, 4, 3, 4, 6, 6, 
      6, 2, 3, 4, 3, 5, 5, 4, 6, 4, 2, 5, 2, 1, 5, 6, 1, 4, 5, 5, 3, 3, 4, 3, 
      6, 3, 4, 2, 3, 4, 1, 6, 6, 6, 6, 1, 2, 6, 6, 5, 6, 4, 6, 4, 6, 4, 4, 2, 
      5, 6, 3, 1, 6, 5, 6, 1, 3, 6, 5, 2, 6, 1, 3, 5, 3, 5, 4, 4, 3, 2, 1, 3, 
      2, 3, 4, 5, 6, 6, 2, 2, 2, 5, 4, 2, 5, 5, 1, 3, 6, 3, 2, 4, 2, 6, 6, 6, 
      4, 3, 1, 4, 2, 1, 3, 5, 1, 5, 3, 4, 5, 1, 3, 5, 5, 4, 5, 1, 5, 5, 4, 1, 
      2, 2, 6, 5, 6, 6, 1, 1, 4, 6, 6, 3, 3, 3, 3, 5, 5, 2, 4, 6, 4, 4, 4, 4, 
      1, 6, 1, 1, 5, 6, 5, 3, 4, 4, 3, 6, 6, 1, 6, 3, 6, 6, 6, 6, 6, 5, 6, 5, 
      3, 4, 2, 5, 3, 5, 1, 3, 2, 3, 5, 4, 1, 5, 3, 1, 1, 4, 6, 6, 4, 6, 6, 6, 
      5, 4, 1, 2, 6, 1, 3, 2, 4, 2, 4, 6, 1, 1, 6, 1, 4, 5, 6, 6, 2, 6, 6, 6, 
      5, 2, 3, 1, 5, 4, 3, 4, 4, 5, 5, 4, 2, 1, 6, 3, 1, 1, 3, 3, 1, 6, 4, 2, 
      4, 5, 1, 6, 2, 2, 2, 6, 2, 1, 6, 4, 1, 4, 4, 2, 3, 1, 3, 1, 1, 1, 3, 2, 
      6, 3, 5, 5, 6, 6, 2, 4, 6, 2, 5, 6, 5}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zust\[ADoubleDot]nde und \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten", "Subsection",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(state = {"\<0\>", "\<F\>", "\<U\>"};\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(observation = {1, 2, 3, 4, 5, 6};\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(emission[z1_, z2_] := 
        Switch[z1, \[IndentingNewLine]"\<F\>", 
          N[1/6], \[IndentingNewLine]"\<U\>", 
          If[z2 \[Equal] 6, 0.5, 0.1], \[IndentingNewLine]"\<0\>", 
          0];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(transition[z1_, z2_] := 
        Switch[{z1, z2}, \[IndentingNewLine]{"\<F\>", "\<F\>"}, 
          0.95, \[IndentingNewLine]{"\<F\>", "\<U\>"}, 
          0.05, \[IndentingNewLine]{"\<U\>", "\<U\>"}, 
          0.90, \[IndentingNewLine]{"\<U\>", "\<F\>"}, 
          0.10, \[IndentingNewLine]{"\<0\>", "\<U\>"}, 
          0.5, \[IndentingNewLine]{"\<0\>", "\<F\>"}, 
          0.5, \[IndentingNewLine]{"\<0\>", "\<0\>"}, 
          0.0, \[IndentingNewLine]{"\<U\>", "\<0\>"}, 
          0.0, \[IndentingNewLine]{"\<F\>", "\<0\>"}, 0.0];\)\)], "Input",
  FontColor->GrayLevel[0.500008]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["forward",
    FontSlant->"Italic"],
  "-Algorithmus"
}], "Subsection",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(L = Length[seq]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(300\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(forward[z1_, 0, x_] := If[z1 == "\<0\>", 1, 0]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(Do[Do[{\(tmpList = 
              Table[forward[state[\([k]\)], i - 1, seq]*
                  transition[state[\([k]\)], state[\([j]\)]], {k, 1, 
                  Length[state]}];\), \[IndentingNewLine]forward[
              state[\([j]\)], i, seq] = 
            emission[state[\([j]\)], 
                seq[\([i]\)]]*\((Plus @@ tmpList)\)}, \[IndentingNewLine]{j, 
          1, Length[state]}], \[IndentingNewLine]{i, 1, L}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      forward[state[\([k]\)], 0, seq], {k, 1, Length[state]}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({1, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      forward[state[\([k]\)], 1, seq], {k, 1, Length[state]}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({0, 0.08333333333333333`, 0.05`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      forward[state[\([k]\)], 2, seq], {k, 1, Length[state]}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({0, 0.014027777777777778`, 0.024583333333333336`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmpList = 
      Table[forward[state[\([k]\)], L, seq], {k, 1, 
          Length[state]}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({0, 4.200040465636647`*^-231, 2.6971646257473115`*^-231}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probSeqForward = Plus @@ tmpList*0.5\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(3.448602545691979`*^-231\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["backward",
    FontSlant->"Italic"],
  "-Algorithmus"
}], "Subsection",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(transitionII[z1_, z2_] := 
      Switch[{z1, z2}, \[IndentingNewLine]{"\<F\>", "\<F\>"}, 
        0.95, \[IndentingNewLine]{"\<F\>", "\<U\>"}, 
        0.05, \[IndentingNewLine]{"\<U\>", "\<U\>"}, 
        0.90, \[IndentingNewLine]{"\<U\>", "\<F\>"}, 
        0.10, \[IndentingNewLine]{"\<0\>", "\<U\>"}, 
        0.0, \[IndentingNewLine]{"\<0\>", "\<F\>"}, 
        0.0, \[IndentingNewLine]{"\<0\>", "\<0\>"}, 
        0.0, \[IndentingNewLine]{"\<U\>", "\<0\>"}, 
        0.5, \[IndentingNewLine]{"\<F\>", "\<0\>"}, 0.5]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(backward[z1_, L, x_] := transitionII[z1, "\<0\>"]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(Do[Do[{\(tmpList = 
              Table[backward[state[\([j]\)], i + 1, seq]*
                  emission[state[\([j]\)], seq[\([i + 1]\)]]*
                  transition[state[\([k]\)], state[\([j]\)]], {j, 1, 
                  Length[state]}];\), \[IndentingNewLine]backward[
              state[\([k]\)], i, seq] = 
            Plus @@ tmpList}, \[IndentingNewLine]{k, 1, 
          Length[state]}], \[IndentingNewLine]{i, L - 1, 
        1, \(-1\)}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      backward[state[\([k]\)], L, seq], {k, 1, Length[state]}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({0.`, 0.5`, 0.5`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmpList = 
      Table[backward[state[\([k]\)], 1, seq], {k, 1, 
          Length[state]}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({3.028055312031167`*^-230, 1.5139865025608112`*^-230, 
      4.373894253782594`*^-230}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probSeqBackward = 
      Plus @@ Table[
          transition["\<0\>", state[\([k]\)]]*
            emission[state[\([k]\)], seq[\([1]\)]]*
            backward[state[\([k]\)], 1, seq], {k, 1, 
            Length[state]}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(3.448602545691973`*^-231\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Posterior-Decodierung", "Subsection",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(Do[\[IndentingNewLine]postDec[state[\([k]\)], i, 
          seq] = \((forward[state[\([k]\)], i, seq]*
              backward[state[\([k]\)], i, seq])\)/
          probSeqBackward, \[IndentingNewLine]{k, 1, 
        Length[state]}, \[IndentingNewLine]{i, 1, L}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(postTable = Table[postDec["\<F\>", i, seq], {i, 1, L}];\)\)], "Input",\

  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[postTable, PlotJoined \[Rule] True, Frame \[Rule] True, 
        AspectRatio \[Rule] 0.3];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.00714286 0.290731 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00714 -6 -4.5 ]
[-0.0125 .00714 0 4.5 ]
[-0.0125 .06529 -18 -4.5 ]
[-0.0125 .06529 0 4.5 ]
[-0.0125 .12344 -18 -4.5 ]
[-0.0125 .12344 0 4.5 ]
[-0.0125 .18158 -18 -4.5 ]
[-0.0125 .18158 0 4.5 ]
[-0.0125 .23973 -18 -4.5 ]
[-0.0125 .23973 0 4.5 ]
[-0.0125 .29787 -6 -4.5 ]
[-0.0125 .29787 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .3 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(50)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(100)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(150)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(200)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(250)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(300)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00714 m
.00625 .00714 L
s
[(0)] -0.0125 .00714 1 0 Mshowa
0 .06529 m
.00625 .06529 L
s
[(0.2)] -0.0125 .06529 1 0 Mshowa
0 .12344 m
.00625 .12344 L
s
[(0.4)] -0.0125 .12344 1 0 Mshowa
0 .18158 m
.00625 .18158 L
s
[(0.6)] -0.0125 .18158 1 0 Mshowa
0 .23973 m
.00625 .23973 L
s
[(0.8)] -0.0125 .23973 1 0 Mshowa
0 .29787 m
.00625 .29787 L
s
[(1)] -0.0125 .29787 1 0 Mshowa
.125 Mabswid
0 .02168 m
.00375 .02168 L
s
0 .03622 m
.00375 .03622 L
s
0 .05075 m
.00375 .05075 L
s
0 .07983 m
.00375 .07983 L
s
0 .09436 m
.00375 .09436 L
s
0 .1089 m
.00375 .1089 L
s
0 .13797 m
.00375 .13797 L
s
0 .15251 m
.00375 .15251 L
s
0 .16704 m
.00375 .16704 L
s
0 .19612 m
.00375 .19612 L
s
0 .21065 m
.00375 .21065 L
s
0 .22519 m
.00375 .22519 L
s
0 .25426 m
.00375 .25426 L
s
0 .2688 m
.00375 .2688 L
s
0 .28334 m
.00375 .28334 L
s
.25 Mabswid
0 0 m
0 .3 L
s
.02381 .29375 m
.02381 .3 L
s
.18254 .29375 m
.18254 .3 L
s
.34127 .29375 m
.34127 .3 L
s
.5 .29375 m
.5 .3 L
s
.65873 .29375 m
.65873 .3 L
s
.81746 .29375 m
.81746 .3 L
s
.97619 .29375 m
.97619 .3 L
s
.125 Mabswid
.05556 .29625 m
.05556 .3 L
s
.0873 .29625 m
.0873 .3 L
s
.11905 .29625 m
.11905 .3 L
s
.15079 .29625 m
.15079 .3 L
s
.21429 .29625 m
.21429 .3 L
s
.24603 .29625 m
.24603 .3 L
s
.27778 .29625 m
.27778 .3 L
s
.30952 .29625 m
.30952 .3 L
s
.37302 .29625 m
.37302 .3 L
s
.40476 .29625 m
.40476 .3 L
s
.43651 .29625 m
.43651 .3 L
s
.46825 .29625 m
.46825 .3 L
s
.53175 .29625 m
.53175 .3 L
s
.56349 .29625 m
.56349 .3 L
s
.59524 .29625 m
.59524 .3 L
s
.62698 .29625 m
.62698 .3 L
s
.69048 .29625 m
.69048 .3 L
s
.72222 .29625 m
.72222 .3 L
s
.75397 .29625 m
.75397 .3 L
s
.78571 .29625 m
.78571 .3 L
s
.84921 .29625 m
.84921 .3 L
s
.88095 .29625 m
.88095 .3 L
s
.9127 .29625 m
.9127 .3 L
s
.94444 .29625 m
.94444 .3 L
s
.25 Mabswid
0 .3 m
1 .3 L
s
.99375 .00714 m
1 .00714 L
s
.99375 .06529 m
1 .06529 L
s
.99375 .12344 m
1 .12344 L
s
.99375 .18158 m
1 .18158 L
s
.99375 .23973 m
1 .23973 L
s
.99375 .29787 m
1 .29787 L
s
.125 Mabswid
.99625 .02168 m
1 .02168 L
s
.99625 .03622 m
1 .03622 L
s
.99625 .05075 m
1 .05075 L
s
.99625 .07983 m
1 .07983 L
s
.99625 .09436 m
1 .09436 L
s
.99625 .1089 m
1 .1089 L
s
.99625 .13797 m
1 .13797 L
s
.99625 .15251 m
1 .15251 L
s
.99625 .16704 m
1 .16704 L
s
.99625 .19612 m
1 .19612 L
s
.99625 .21065 m
1 .21065 L
s
.99625 .22519 m
1 .22519 L
s
.99625 .25426 m
1 .25426 L
s
.99625 .2688 m
1 .2688 L
s
.99625 .28334 m
1 .28334 L
s
.25 Mabswid
1 0 m
1 .3 L
s
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
.5 Mabswid
.02698 .11351 m
.03016 .10263 L
.03333 .11354 L
.03651 .15958 L
.03968 .18283 L
.04286 .1915 L
.04603 .18865 L
.04921 .21234 L
.05238 .22251 L
.05556 .22275 L
.05873 .21314 L
.0619 .19028 L
.06508 .19369 L
.06825 .18573 L
.07143 .20273 L
.0746 .20748 L
.07778 .20168 L
.08095 .18327 L
.08413 .1901 L
.0873 .18543 L
.09048 .16762 L
.09365 .13038 L
.09683 .12443 L
.1 .14249 L
.10317 .20667 L
.10635 .24222 L
.10952 .2617 L
.1127 .27198 L
.11587 .27669 L
.11905 .2775 L
.12222 .27468 L
.1254 .26726 L
.12857 .2776 L
.13175 .28305 L
.13492 .28553 L
.1381 .28592 L
.14127 .28436 L
.14444 .28029 L
.14762 .27227 L
.15079 .28093 L
.15397 .28557 L
.15714 .28786 L
.16032 .28858 L
.16349 .28801 L
.16667 .28593 L
.16984 .28162 L
.17302 .27354 L
.17619 .25884 L
.17937 .26394 L
.18254 .26334 L
Mistroke
.18571 .25683 L
.18889 .24213 L
.19206 .21404 L
.19524 .16264 L
.19841 .06977 L
.20159 .038 L
.20476 .02843 L
.20794 .02932 L
.21111 .0418 L
.21429 .0426 L
.21746 .03202 L
.22063 .03302 L
.22381 .04683 L
.22698 .0484 L
.23016 .06717 L
.23333 .07174 L
.23651 .10016 L
.23968 .1112 L
.24286 .15733 L
.24603 .18059 L
.24921 .18919 L
.25238 .18618 L
.25556 .17048 L
.25873 .17965 L
.2619 .17676 L
.26508 .1608 L
.26825 .16967 L
.27143 .16615 L
.2746 .18897 L
.27778 .19755 L
.28095 .1949 L
.28413 .21874 L
.2873 .22932 L
.29048 .23038 L
.29365 .25808 L
.29683 .2735 L
.3 .28208 L
.30317 .28683 L
.30635 .28945 L
.30952 .29086 L
.3127 .29155 L
.31587 .29178 L
.31905 .29161 L
.32222 .29099 L
.3254 .28969 L
.32857 .28727 L
.33175 .28287 L
.33492 .27493 L
.3381 .26065 L
.34127 .23499 L
Mistroke
.34444 .23488 L
.34762 .26019 L
.35079 .27421 L
.35397 .28189 L
.35714 .28594 L
.36032 .28781 L
.36349 .28813 L
.36667 .28704 L
.36984 .28413 L
.37302 .2784 L
.37619 .2678 L
.37937 .24861 L
.38254 .25159 L
.38571 .24753 L
.38889 .235 L
.39206 .20956 L
.39524 .16225 L
.39841 .15199 L
.40159 .16623 L
.40476 .22241 L
.40794 .25369 L
.41111 .27109 L
.41429 .28078 L
.41746 .28618 L
.42063 .28918 L
.42381 .29085 L
.42698 .29178 L
.43016 .29229 L
.43333 .29258 L
.43651 .29274 L
.43968 .29282 L
.44286 .29285 L
.44603 .29286 L
.44921 .29283 L
.45238 .29276 L
.45556 .29262 L
.45873 .29237 L
.4619 .29191 L
.46508 .29109 L
.46825 .28961 L
.47143 .28696 L
.4746 .28218 L
.47778 .27361 L
.48095 .25821 L
.48413 .23054 L
.4873 .18084 L
.49048 .16959 L
.49365 .14217 L
.49683 .1422 L
.5 .1697 L
Mistroke
.50317 .181 L
.50635 .1801 L
.50952 .16667 L
.5127 .17792 L
.51587 .22762 L
.51905 .25517 L
.52222 .27031 L
.5254 .27836 L
.52857 .28219 L
.53175 .28313 L
.53492 .28153 L
.5381 .27681 L
.54127 .26732 L
.54444 .27553 L
.54762 .27909 L
.55079 .27924 L
.55397 .27605 L
.55714 .2684 L
.56032 .25357 L
.56349 .25922 L
.56667 .25859 L
.56984 .25143 L
.57302 .23524 L
.57619 .24163 L
.57937 .23992 L
.58254 .22951 L
.58571 .20672 L
.58889 .16351 L
.59206 .08461 L
.59524 .05878 L
.59841 .05439 L
.60159 .03641 L
.60476 .03349 L
.60794 .019 L
.61111 .01461 L
.61429 .01494 L
.61746 .02042 L
.62063 .03773 L
.62381 .08809 L
.62698 .11321 L
.63016 .19287 L
.63333 .23721 L
.63651 .26189 L
.63968 .27563 L
.64286 .28326 L
.64603 .2875 L
.64921 .28983 L
.65238 .29107 L
.65556 .29168 L
.65873 .29185 L
Mistroke
.6619 .29166 L
.66508 .29103 L
.66825 .28975 L
.67143 .28735 L
.6746 .28299 L
.67778 .27514 L
.68095 .26102 L
.68413 .23565 L
.6873 .19006 L
.69048 .10816 L
.69365 .08201 L
.69683 .07958 L
.7 .06322 L
.70317 .06523 L
.70635 .08807 L
.70952 .15972 L
.7127 .19856 L
.71587 .2183 L
.71905 .22592 L
.72222 .2241 L
.7254 .24764 L
.72857 .25966 L
.73175 .2644 L
.73492 .26353 L
.7381 .25674 L
.74127 .24164 L
.74444 .2129 L
.74762 .21196 L
.75079 .20024 L
.75397 .17359 L
.75714 .17456 L
.76032 .16307 L
.76349 .13507 L
.76667 .08066 L
.76984 .0645 L
.77302 .06683 L
.77619 .05656 L
.77937 .06252 L
.78254 .09198 L
.78571 .18102 L
.78889 .23059 L
.79206 .25817 L
.79524 .27351 L
.79841 .28204 L
.80159 .28675 L
.80476 .28932 L
.80794 .29065 L
.81111 .29121 L
.81429 .2912 L
.81746 .29061 L
Mistroke
.82063 .28925 L
.82381 .28661 L
.82698 .28179 L
.83016 .27306 L
.83333 .28084 L
.83651 .28481 L
.83968 .28637 L
.84286 .28608 L
.84603 .28382 L
.84921 .27882 L
.85238 .2693 L
.85556 .2771 L
.85873 .28055 L
.8619 .28086 L
.86508 .27814 L
.86825 .27144 L
.87143 .25838 L
.8746 .26486 L
.87778 .26561 L
.88095 .26091 L
.88413 .2491 L
.8873 .25788 L
.89048 .25984 L
.89365 .25567 L
.89683 .27212 L
.9 .28127 L
.90317 .28633 L
.90635 .28909 L
.90952 .29053 L
.9127 .29117 L
.91587 .29122 L
.91905 .29071 L
.92222 .28944 L
.9254 .28698 L
.92857 .28246 L
.93175 .27428 L
.93492 .25954 L
.9381 .23306 L
.94127 .23257 L
.94444 .22292 L
.94762 .20071 L
.95079 .15809 L
.95397 .15005 L
.95714 .16673 L
.96032 .16988 L
.96349 .16062 L
.96667 .17613 L
.96984 .17863 L
.97302 .169 L
.97619 .18418 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 86.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0.500008],
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000ER000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool200000200oooo0P0000040?ooo`8000006@3oool500000080oooo0P0000040?oo
o`8000005P3oool500000080oooo0P0000040?ooo`8000005@3oool4000000<0oooo0P0000040?oo
o`8000005P3oool4000000<0oooo0P0000040?ooo`8000005`3oool2000000@0oooo0P0000040?oo
o`8000004`3oool002L0oooo00@000000?ooo`3oool000007P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000E0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000B0?ooo`009`3oool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo000W
0?ooo`040000003oool0oooo000001l0oooo0P0000030?ooo`040000003oool0oooo000001X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`00000F
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool0
0000603oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0403oool002L0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000001X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000005@3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000005@3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
4P3oool002P0oooo0P00000P0?ooo`<000000`3oool2000001X0oooo0P0000040?ooo`800000103o
ool2000001L0oooo0P0000040?ooo`<000000`3oool2000001H0oooo0P0000040?ooo`800000103o
ool2000001L0oooo0P0000040?ooo`<000000`3oool2000001L0oooo0P0000040?ooo`800000103o
ool2000001<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo000M0?ooo`8000001@3ooooX000001@0oooo000L0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0180oooo000L0?ooo`040000003oool0oooo000000@0oooo0P00003T0?ooo`800000503oool0
01`0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2:0?ooo`800000F03oool0
0`000000oooo0?ooo`0B0?ooo`00703oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo08X0oooo0P00001H0?ooo`030000003oool0oooo0180oooo000M0?ooo`8000001@3oool20000
08/0oooo00<000000?ooo`000000E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`290?ooo`040000003oool0oooo000005L0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0;03oool2000000030?ooo`000000oooo05P0oooo00@000000?ooo`3o
ool00000E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000002d0oooo0P0000000`3oool0
00000000001G0?ooo`8000000`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`0000000P00001G0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`0/0?ooo`060000003oool000000000003oool00000EP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000T0?ooo`800000;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000A
0?ooo`800000103oool2000000<0oooo100000040?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0180oooo000@0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0200oooo0P00000b0?ooo`030000003oool0oooo0180oooo000@0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool2000002`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03`3oool2000000h0oooo0`00000a0?ooo`800000503oool00100oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03`3oool2000000h0oooo00<000000?ooo`000000<P3oool00`000000oooo0?ooo`0B
0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000d0oooo00@0
00000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0B0?ooo`004@3oool2000000X0oooo0P00
00050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000
000=0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool2000002`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000=0?ooo`050000003o
ool0oooo0?ooo`000000<@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003@3oool01@000000oooo0?oo
o`3oool000000340oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000d0oooo00D000000?ooo`3oool0oooo
0000000a0?ooo`030000003oool0oooo0180oooo000T0?ooo`800000;03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0=0?ooo`040000003oool0oooo000000d0oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`00000=0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000=0?ooo`050000003oool0oooo
0?ooo`000000<@3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000000@0oooo0P00000V0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool000003@3oool01@000000oooo0?ooo`3o
ool000000340oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0000000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000003@3o
ool01@000000oooo0?ooo`3oool000000340oooo00<000000?ooo`3oool04P3oool00140oooo0P00
00040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000003@3oool01@000000oooo
0?ooo`3oool000000340oooo00<000000?ooo`3oool04P3oool00100oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000d0oooo00D000000?oo
o`3oool0oooo0000000a0?ooo`030000003oool0oooo0180oooo000@0?ooo`040000003oool0oooo
000000P0oooo1@0000030?ooo`8000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000`0oooo00D0
00000?ooo`3oool0oooo0000000`0?ooo`800000503oool00100oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3o
ool0oooo0000000<0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`000000oooo0?ooo`0B
0?ooo`00403oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000`0oooo00D000000?ooo`3oool0oooo
0000000a0?ooo`030000003oool0oooo0180oooo000A0?ooo`8000002`3oool2000000@0oooo0P00
00060?ooo`030000003oool0oooo00/0oooo0P00000E0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00/0oooo0P00000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=`3o
ool2000001@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`050000003o
ool0oooo0?ooo`000000303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0;0?ooo`8000005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03L0oooo0P00
000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool01@000000oooo0?oo
o`3oool0000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0180oooo000T0?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01<0oooo0P00000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo01<0oooo0P00000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0S0?ooo`8000002@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000005@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool20000
01D0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool08`3oool2000000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000001/0oooo00<000000?ooo`000000503oool00`000000oooo0000000C0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`04
0000003oool00000000000L0oooo00<000000?ooo`3oool04P3oool002@0oooo0P0000060?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`080?ooo`05
0000003oool0oooo0000003oool00`00000K0?ooo`030000003oool0000001@0oooo00D000000?oo
o`000000oooo0000000A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0S0?ooo`060000003oool000000000003oool000001@3oool00`000000oooo
0?ooo`0B0?ooo`004@3oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000005@3oool00`000000oooo0?oo
o`090?ooo`070000003oool000000?ooo`000000oooo0000000K0?ooo`030000003oool0000001@0
oooo00D000000?ooo`000000oooo0000000A0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo0?ooo`8000001@3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003o
ool0oooo0?ooo`000000503oool00`000000oooo0?ooo`090?ooo`80000000D0oooo000000000000
oooo0000000K0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool00P0000000`3oool0
00000?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0S0?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`0B0?oo
o`00403oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P000007
0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02@3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0603oool0
0`000000oooo0000000C0?ooo`030000003oool0oooo0080000000<0oooo0000003oool03`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000503oool00100oooo00@00000
0?ooo`3oool00000203oool3000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000004`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo000@0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`8000000P3o
ool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0000001<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool04P3oool00140oooo0P00000:0?ooo`<00000103oool2
000000T0oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`040?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool2000001T0oooo00<000000?ooo`0000004`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`080?ooo`080000003oool0oooo
0000003oool000000?ooo`0000050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool2000001T0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`080?ooo`080000003oool0oooo0000003oool000000?ooo`000005
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000000T0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000002@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo0000
0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool02@3oool2000000X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000000X0
oooo0P00000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`80
00005P3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00140
oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool2000000T0
oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0000000;0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool07`3oool2000000`0oooo00<000000?ooo`3oool04P3oool00100oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo0P000009
0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00/0oooo0P00000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0180oooo000@0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool2000001L0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0
oooo0`00000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?oo
o`800000503oool00100oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo000000080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0B0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000070?ooo`800000103o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo000A0?ooo`8000002P3o
ool2000000D0oooo0P00000G0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool2000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0000000/0oooo00<000000?ooo`3oool04P3oool2000000030?ooo`000000oooo00L0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00d0oooo0P00000I0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo0P00000<0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`0000000`0000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`8000006@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool20000
00`0oooo00<000000?ooo`3oool0403oool2000000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo000T0?ooo`8000005`3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00X0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo01L0oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo01P0oooo0P000000103oool000000?ooo`3oool2000000@0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`02000000030?ooo`000000oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80000000<0oooo0000003oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool06`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo000000020?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000`3oool010000000oooo0000000000070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000001`0oooo100000020?oo
o`040000003oool0oooo000001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`040000003oool00000000000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`00000<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`00703oool5
000000<0oooo00<000000?ooo`3oool08@3oool300000200oooo0P0000020?ooo`8000001P3oool2
000000`0oooo0P0000090?ooo`030000003oool0oooo02L0oooo0P0000020?ooo`8000007P3oool5
000001<0oooo1000000A0?ooo`030000003oool0oooo0180oooo000N0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01/0oooo0`0000040?ooo`030000003oool0oooo0140oooo2@0000080?ooo`030000003oool0oooo
0240oooo0P00000S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0B0?ooo`007P3oool00`000000oooo0?ooo`030?ooonP00000503oool001h0oooo
00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001d0oooo0P00003o
0?ooo`80oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {85.375, 0}} -> {-57.035, -0.201246, 1.36025, \
0.014853}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualisierung des Resultats", "Subsection",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plpost = 
        ListPlot[postTable, PlotJoined \[Rule] True, Frame \[Rule] True, 
          AspectRatio \[Rule] 0.3];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.00714286 0.290731 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00714 -6 -4.5 ]
[-0.0125 .00714 0 4.5 ]
[-0.0125 .06529 -18 -4.5 ]
[-0.0125 .06529 0 4.5 ]
[-0.0125 .12344 -18 -4.5 ]
[-0.0125 .12344 0 4.5 ]
[-0.0125 .18158 -18 -4.5 ]
[-0.0125 .18158 0 4.5 ]
[-0.0125 .23973 -18 -4.5 ]
[-0.0125 .23973 0 4.5 ]
[-0.0125 .29787 -6 -4.5 ]
[-0.0125 .29787 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .3 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(50)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(100)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(150)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(200)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(250)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(300)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00714 m
.00625 .00714 L
s
[(0)] -0.0125 .00714 1 0 Mshowa
0 .06529 m
.00625 .06529 L
s
[(0.2)] -0.0125 .06529 1 0 Mshowa
0 .12344 m
.00625 .12344 L
s
[(0.4)] -0.0125 .12344 1 0 Mshowa
0 .18158 m
.00625 .18158 L
s
[(0.6)] -0.0125 .18158 1 0 Mshowa
0 .23973 m
.00625 .23973 L
s
[(0.8)] -0.0125 .23973 1 0 Mshowa
0 .29787 m
.00625 .29787 L
s
[(1)] -0.0125 .29787 1 0 Mshowa
.125 Mabswid
0 .02168 m
.00375 .02168 L
s
0 .03622 m
.00375 .03622 L
s
0 .05075 m
.00375 .05075 L
s
0 .07983 m
.00375 .07983 L
s
0 .09436 m
.00375 .09436 L
s
0 .1089 m
.00375 .1089 L
s
0 .13797 m
.00375 .13797 L
s
0 .15251 m
.00375 .15251 L
s
0 .16704 m
.00375 .16704 L
s
0 .19612 m
.00375 .19612 L
s
0 .21065 m
.00375 .21065 L
s
0 .22519 m
.00375 .22519 L
s
0 .25426 m
.00375 .25426 L
s
0 .2688 m
.00375 .2688 L
s
0 .28334 m
.00375 .28334 L
s
.25 Mabswid
0 0 m
0 .3 L
s
.02381 .29375 m
.02381 .3 L
s
.18254 .29375 m
.18254 .3 L
s
.34127 .29375 m
.34127 .3 L
s
.5 .29375 m
.5 .3 L
s
.65873 .29375 m
.65873 .3 L
s
.81746 .29375 m
.81746 .3 L
s
.97619 .29375 m
.97619 .3 L
s
.125 Mabswid
.05556 .29625 m
.05556 .3 L
s
.0873 .29625 m
.0873 .3 L
s
.11905 .29625 m
.11905 .3 L
s
.15079 .29625 m
.15079 .3 L
s
.21429 .29625 m
.21429 .3 L
s
.24603 .29625 m
.24603 .3 L
s
.27778 .29625 m
.27778 .3 L
s
.30952 .29625 m
.30952 .3 L
s
.37302 .29625 m
.37302 .3 L
s
.40476 .29625 m
.40476 .3 L
s
.43651 .29625 m
.43651 .3 L
s
.46825 .29625 m
.46825 .3 L
s
.53175 .29625 m
.53175 .3 L
s
.56349 .29625 m
.56349 .3 L
s
.59524 .29625 m
.59524 .3 L
s
.62698 .29625 m
.62698 .3 L
s
.69048 .29625 m
.69048 .3 L
s
.72222 .29625 m
.72222 .3 L
s
.75397 .29625 m
.75397 .3 L
s
.78571 .29625 m
.78571 .3 L
s
.84921 .29625 m
.84921 .3 L
s
.88095 .29625 m
.88095 .3 L
s
.9127 .29625 m
.9127 .3 L
s
.94444 .29625 m
.94444 .3 L
s
.25 Mabswid
0 .3 m
1 .3 L
s
.99375 .00714 m
1 .00714 L
s
.99375 .06529 m
1 .06529 L
s
.99375 .12344 m
1 .12344 L
s
.99375 .18158 m
1 .18158 L
s
.99375 .23973 m
1 .23973 L
s
.99375 .29787 m
1 .29787 L
s
.125 Mabswid
.99625 .02168 m
1 .02168 L
s
.99625 .03622 m
1 .03622 L
s
.99625 .05075 m
1 .05075 L
s
.99625 .07983 m
1 .07983 L
s
.99625 .09436 m
1 .09436 L
s
.99625 .1089 m
1 .1089 L
s
.99625 .13797 m
1 .13797 L
s
.99625 .15251 m
1 .15251 L
s
.99625 .16704 m
1 .16704 L
s
.99625 .19612 m
1 .19612 L
s
.99625 .21065 m
1 .21065 L
s
.99625 .22519 m
1 .22519 L
s
.99625 .25426 m
1 .25426 L
s
.99625 .2688 m
1 .2688 L
s
.99625 .28334 m
1 .28334 L
s
.25 Mabswid
1 0 m
1 .3 L
s
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
.5 Mabswid
.02698 .11351 m
.03016 .10263 L
.03333 .11354 L
.03651 .15958 L
.03968 .18283 L
.04286 .1915 L
.04603 .18865 L
.04921 .21234 L
.05238 .22251 L
.05556 .22275 L
.05873 .21314 L
.0619 .19028 L
.06508 .19369 L
.06825 .18573 L
.07143 .20273 L
.0746 .20748 L
.07778 .20168 L
.08095 .18327 L
.08413 .1901 L
.0873 .18543 L
.09048 .16762 L
.09365 .13038 L
.09683 .12443 L
.1 .14249 L
.10317 .20667 L
.10635 .24222 L
.10952 .2617 L
.1127 .27198 L
.11587 .27669 L
.11905 .2775 L
.12222 .27468 L
.1254 .26726 L
.12857 .2776 L
.13175 .28305 L
.13492 .28553 L
.1381 .28592 L
.14127 .28436 L
.14444 .28029 L
.14762 .27227 L
.15079 .28093 L
.15397 .28557 L
.15714 .28786 L
.16032 .28858 L
.16349 .28801 L
.16667 .28593 L
.16984 .28162 L
.17302 .27354 L
.17619 .25884 L
.17937 .26394 L
.18254 .26334 L
Mistroke
.18571 .25683 L
.18889 .24213 L
.19206 .21404 L
.19524 .16264 L
.19841 .06977 L
.20159 .038 L
.20476 .02843 L
.20794 .02932 L
.21111 .0418 L
.21429 .0426 L
.21746 .03202 L
.22063 .03302 L
.22381 .04683 L
.22698 .0484 L
.23016 .06717 L
.23333 .07174 L
.23651 .10016 L
.23968 .1112 L
.24286 .15733 L
.24603 .18059 L
.24921 .18919 L
.25238 .18618 L
.25556 .17048 L
.25873 .17965 L
.2619 .17676 L
.26508 .1608 L
.26825 .16967 L
.27143 .16615 L
.2746 .18897 L
.27778 .19755 L
.28095 .1949 L
.28413 .21874 L
.2873 .22932 L
.29048 .23038 L
.29365 .25808 L
.29683 .2735 L
.3 .28208 L
.30317 .28683 L
.30635 .28945 L
.30952 .29086 L
.3127 .29155 L
.31587 .29178 L
.31905 .29161 L
.32222 .29099 L
.3254 .28969 L
.32857 .28727 L
.33175 .28287 L
.33492 .27493 L
.3381 .26065 L
.34127 .23499 L
Mistroke
.34444 .23488 L
.34762 .26019 L
.35079 .27421 L
.35397 .28189 L
.35714 .28594 L
.36032 .28781 L
.36349 .28813 L
.36667 .28704 L
.36984 .28413 L
.37302 .2784 L
.37619 .2678 L
.37937 .24861 L
.38254 .25159 L
.38571 .24753 L
.38889 .235 L
.39206 .20956 L
.39524 .16225 L
.39841 .15199 L
.40159 .16623 L
.40476 .22241 L
.40794 .25369 L
.41111 .27109 L
.41429 .28078 L
.41746 .28618 L
.42063 .28918 L
.42381 .29085 L
.42698 .29178 L
.43016 .29229 L
.43333 .29258 L
.43651 .29274 L
.43968 .29282 L
.44286 .29285 L
.44603 .29286 L
.44921 .29283 L
.45238 .29276 L
.45556 .29262 L
.45873 .29237 L
.4619 .29191 L
.46508 .29109 L
.46825 .28961 L
.47143 .28696 L
.4746 .28218 L
.47778 .27361 L
.48095 .25821 L
.48413 .23054 L
.4873 .18084 L
.49048 .16959 L
.49365 .14217 L
.49683 .1422 L
.5 .1697 L
Mistroke
.50317 .181 L
.50635 .1801 L
.50952 .16667 L
.5127 .17792 L
.51587 .22762 L
.51905 .25517 L
.52222 .27031 L
.5254 .27836 L
.52857 .28219 L
.53175 .28313 L
.53492 .28153 L
.5381 .27681 L
.54127 .26732 L
.54444 .27553 L
.54762 .27909 L
.55079 .27924 L
.55397 .27605 L
.55714 .2684 L
.56032 .25357 L
.56349 .25922 L
.56667 .25859 L
.56984 .25143 L
.57302 .23524 L
.57619 .24163 L
.57937 .23992 L
.58254 .22951 L
.58571 .20672 L
.58889 .16351 L
.59206 .08461 L
.59524 .05878 L
.59841 .05439 L
.60159 .03641 L
.60476 .03349 L
.60794 .019 L
.61111 .01461 L
.61429 .01494 L
.61746 .02042 L
.62063 .03773 L
.62381 .08809 L
.62698 .11321 L
.63016 .19287 L
.63333 .23721 L
.63651 .26189 L
.63968 .27563 L
.64286 .28326 L
.64603 .2875 L
.64921 .28983 L
.65238 .29107 L
.65556 .29168 L
.65873 .29185 L
Mistroke
.6619 .29166 L
.66508 .29103 L
.66825 .28975 L
.67143 .28735 L
.6746 .28299 L
.67778 .27514 L
.68095 .26102 L
.68413 .23565 L
.6873 .19006 L
.69048 .10816 L
.69365 .08201 L
.69683 .07958 L
.7 .06322 L
.70317 .06523 L
.70635 .08807 L
.70952 .15972 L
.7127 .19856 L
.71587 .2183 L
.71905 .22592 L
.72222 .2241 L
.7254 .24764 L
.72857 .25966 L
.73175 .2644 L
.73492 .26353 L
.7381 .25674 L
.74127 .24164 L
.74444 .2129 L
.74762 .21196 L
.75079 .20024 L
.75397 .17359 L
.75714 .17456 L
.76032 .16307 L
.76349 .13507 L
.76667 .08066 L
.76984 .0645 L
.77302 .06683 L
.77619 .05656 L
.77937 .06252 L
.78254 .09198 L
.78571 .18102 L
.78889 .23059 L
.79206 .25817 L
.79524 .27351 L
.79841 .28204 L
.80159 .28675 L
.80476 .28932 L
.80794 .29065 L
.81111 .29121 L
.81429 .2912 L
.81746 .29061 L
Mistroke
.82063 .28925 L
.82381 .28661 L
.82698 .28179 L
.83016 .27306 L
.83333 .28084 L
.83651 .28481 L
.83968 .28637 L
.84286 .28608 L
.84603 .28382 L
.84921 .27882 L
.85238 .2693 L
.85556 .2771 L
.85873 .28055 L
.8619 .28086 L
.86508 .27814 L
.86825 .27144 L
.87143 .25838 L
.8746 .26486 L
.87778 .26561 L
.88095 .26091 L
.88413 .2491 L
.8873 .25788 L
.89048 .25984 L
.89365 .25567 L
.89683 .27212 L
.9 .28127 L
.90317 .28633 L
.90635 .28909 L
.90952 .29053 L
.9127 .29117 L
.91587 .29122 L
.91905 .29071 L
.92222 .28944 L
.9254 .28698 L
.92857 .28246 L
.93175 .27428 L
.93492 .25954 L
.9381 .23306 L
.94127 .23257 L
.94444 .22292 L
.94762 .20071 L
.95079 .15809 L
.95397 .15005 L
.95714 .16673 L
.96032 .16988 L
.96349 .16062 L
.96667 .17613 L
.96984 .17863 L
.97302 .169 L
.97619 .18418 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 86.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0.500008],
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000ER000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool200000200oooo0P0000040?ooo`8000006@3oool500000080oooo0P0000040?oo
o`8000005P3oool500000080oooo0P0000040?ooo`8000005@3oool4000000<0oooo0P0000040?oo
o`8000005P3oool4000000<0oooo0P0000040?ooo`8000005`3oool2000000@0oooo0P0000040?oo
o`8000004`3oool002L0oooo00@000000?ooo`3oool000007P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000E0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000B0?ooo`009`3oool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo000W
0?ooo`040000003oool0oooo000001l0oooo0P0000030?ooo`040000003oool0oooo000001X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`00000F
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool0
0000603oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0403oool002L0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000001X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000005@3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000005@3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
4P3oool002P0oooo0P00000P0?ooo`<000000`3oool2000001X0oooo0P0000040?ooo`800000103o
ool2000001L0oooo0P0000040?ooo`<000000`3oool2000001H0oooo0P0000040?ooo`800000103o
ool2000001L0oooo0P0000040?ooo`<000000`3oool2000001L0oooo0P0000040?ooo`800000103o
ool2000001<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo000M0?ooo`8000001@3ooooX000001@0oooo000L0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0180oooo000L0?ooo`040000003oool0oooo000000@0oooo0P00003T0?ooo`800000503oool0
01`0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2:0?ooo`800000F03oool0
0`000000oooo0?ooo`0B0?ooo`00703oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo08X0oooo0P00001H0?ooo`030000003oool0oooo0180oooo000M0?ooo`8000001@3oool20000
08/0oooo00<000000?ooo`000000E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`290?ooo`040000003oool0oooo000005L0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0;03oool2000000030?ooo`000000oooo05P0oooo00@000000?ooo`3o
ool00000E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000002d0oooo0P0000000`3oool0
00000000001G0?ooo`8000000`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`0000000P00001G0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`0/0?ooo`060000003oool000000000003oool00000EP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000T0?ooo`800000;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000A
0?ooo`800000103oool2000000<0oooo100000040?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0180oooo000@0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0200oooo0P00000b0?ooo`030000003oool0oooo0180oooo000@0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool2000002`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03`3oool2000000h0oooo0`00000a0?ooo`800000503oool00100oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03`3oool2000000h0oooo00<000000?ooo`000000<P3oool00`000000oooo0?ooo`0B
0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000d0oooo00@0
00000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0B0?ooo`004@3oool2000000X0oooo0P00
00050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000
000=0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool2000002`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000=0?ooo`050000003o
ool0oooo0?ooo`000000<@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003@3oool01@000000oooo0?oo
o`3oool000000340oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000d0oooo00D000000?ooo`3oool0oooo
0000000a0?ooo`030000003oool0oooo0180oooo000T0?ooo`800000;03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0=0?ooo`040000003oool0oooo000000d0oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`00000=0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000=0?ooo`050000003oool0oooo
0?ooo`000000<@3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000000@0oooo0P00000V0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool000003@3oool01@000000oooo0?ooo`3o
ool000000340oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0000000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000003@3o
ool01@000000oooo0?ooo`3oool000000340oooo00<000000?ooo`3oool04P3oool00140oooo0P00
00040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000003@3oool01@000000oooo
0?ooo`3oool000000340oooo00<000000?ooo`3oool04P3oool00100oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000d0oooo00D000000?oo
o`3oool0oooo0000000a0?ooo`030000003oool0oooo0180oooo000@0?ooo`040000003oool0oooo
000000P0oooo1@0000030?ooo`8000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000`0oooo00D0
00000?ooo`3oool0oooo0000000`0?ooo`800000503oool00100oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3o
ool0oooo0000000<0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`000000oooo0?ooo`0B
0?ooo`00403oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000`0oooo00D000000?ooo`3oool0oooo
0000000a0?ooo`030000003oool0oooo0180oooo000A0?ooo`8000002`3oool2000000@0oooo0P00
00060?ooo`030000003oool0oooo00/0oooo0P00000E0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00/0oooo0P00000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=`3o
ool2000001@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`050000003o
ool0oooo0?ooo`000000303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0;0?ooo`8000005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03L0oooo0P00
000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool01@000000oooo0?oo
o`3oool0000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0180oooo000T0?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01<0oooo0P00000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo01<0oooo0P00000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0S0?ooo`8000002@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000005@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool20000
01D0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool08`3oool2000000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000001/0oooo00<000000?ooo`000000503oool00`000000oooo0000000C0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`04
0000003oool00000000000L0oooo00<000000?ooo`3oool04P3oool002@0oooo0P0000060?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`080?ooo`05
0000003oool0oooo0000003oool00`00000K0?ooo`030000003oool0000001@0oooo00D000000?oo
o`000000oooo0000000A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0S0?ooo`060000003oool000000000003oool000001@3oool00`000000oooo
0?ooo`0B0?ooo`004@3oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000005@3oool00`000000oooo0?oo
o`090?ooo`070000003oool000000?ooo`000000oooo0000000K0?ooo`030000003oool0000001@0
oooo00D000000?ooo`000000oooo0000000A0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo0?ooo`8000001@3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003o
ool0oooo0?ooo`000000503oool00`000000oooo0?ooo`090?ooo`80000000D0oooo000000000000
oooo0000000K0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool00P0000000`3oool0
00000?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0S0?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`0B0?oo
o`00403oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P000007
0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02@3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0603oool0
0`000000oooo0000000C0?ooo`030000003oool0oooo0080000000<0oooo0000003oool03`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000503oool00100oooo00@00000
0?ooo`3oool00000203oool3000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000004`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo000@0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`8000000P3o
ool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0000001<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool04P3oool00140oooo0P00000:0?ooo`<00000103oool2
000000T0oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`040?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool2000001T0oooo00<000000?ooo`0000004`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`080?ooo`080000003oool0oooo
0000003oool000000?ooo`0000050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool2000001T0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`080?ooo`080000003oool0oooo0000003oool000000?ooo`000005
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000000T0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000002@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo0000
0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool02@3oool2000000X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000000X0
oooo0P00000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`80
00005P3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00140
oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool2000000T0
oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0000000;0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool07`3oool2000000`0oooo00<000000?ooo`3oool04P3oool00100oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo0P000009
0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00/0oooo0P00000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0180oooo000@0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool2000001L0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0
oooo0`00000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?oo
o`800000503oool00100oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo000000080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0B0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000070?ooo`800000103o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo000A0?ooo`8000002P3o
ool2000000D0oooo0P00000G0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool2000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0000000/0oooo00<000000?ooo`3oool04P3oool2000000030?ooo`000000oooo00L0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00d0oooo0P00000I0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo0P00000<0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`0000000`0000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`8000006@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool20000
00`0oooo00<000000?ooo`3oool0403oool2000000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo000T0?ooo`8000005`3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00X0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo01L0oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo01P0oooo0P000000103oool000000?ooo`3oool2000000@0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`02000000030?ooo`000000oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80000000<0oooo0000003oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool06`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo000000020?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000`3oool010000000oooo0000000000070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`00903oool2000001`0oooo100000020?oo
o`040000003oool0oooo000001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`040000003oool00000000000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`00000<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`00703oool5
000000<0oooo00<000000?ooo`3oool08@3oool300000200oooo0P0000020?ooo`8000001P3oool2
000000`0oooo0P0000090?ooo`030000003oool0oooo02L0oooo0P0000020?ooo`8000007P3oool5
000001<0oooo1000000A0?ooo`030000003oool0oooo0180oooo000N0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01/0oooo0`0000040?ooo`030000003oool0oooo0140oooo2@0000080?ooo`030000003oool0oooo
0240oooo0P00000S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0B0?ooo`007P3oool00`000000oooo0?ooo`030?ooonP00000503oool001h0oooo
00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool0o`3oool001d0oooo0P00003o
0?ooo`80oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {85.375, 0}} -> {-57.035, -0.201246, 1.36025, \
0.014853}}]
}, Open  ]],

Cell[BoxData[
    \(\(label1 = 
        stateSeq /. {"\<F\>" \[Rule] 0, "\<U\>" \[Rule] 1};\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(coord1 = 
      Flatten[Position[Abs[label1 - RotateLeft[label1, 1]], 1]]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({20, 22, 54, 68, 79, 85, 146, 149, 176, 187, 211, 220, 232, 239, 291, 
      294, 299, 300}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(rectangleList = 
        Map[{GrayLevel[0.9], Rectangle[{#[\([1]\)], 0}, {#[\([2]\)], 1}]} &, 
          Partition[coord1, 2]];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(\(plrectangle = 
        Show[Graphics[rectangleList], AspectRatio \[Rule] 0.3, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[plpost, plrectangle, plpost, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.00714286 0.285714 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00714 -6 -4.5 ]
[-0.0125 .00714 0 4.5 ]
[-0.0125 .06429 -18 -4.5 ]
[-0.0125 .06429 0 4.5 ]
[-0.0125 .12143 -18 -4.5 ]
[-0.0125 .12143 0 4.5 ]
[-0.0125 .17857 -18 -4.5 ]
[-0.0125 .17857 0 4.5 ]
[-0.0125 .23571 -18 -4.5 ]
[-0.0125 .23571 0 4.5 ]
[-0.0125 .29286 -6 -4.5 ]
[-0.0125 .29286 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .3 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(50)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(100)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(150)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(200)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(250)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(300)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00714 m
.00625 .00714 L
s
[(0)] -0.0125 .00714 1 0 Mshowa
0 .06429 m
.00625 .06429 L
s
[(0.2)] -0.0125 .06429 1 0 Mshowa
0 .12143 m
.00625 .12143 L
s
[(0.4)] -0.0125 .12143 1 0 Mshowa
0 .17857 m
.00625 .17857 L
s
[(0.6)] -0.0125 .17857 1 0 Mshowa
0 .23571 m
.00625 .23571 L
s
[(0.8)] -0.0125 .23571 1 0 Mshowa
0 .29286 m
.00625 .29286 L
s
[(1)] -0.0125 .29286 1 0 Mshowa
.125 Mabswid
0 .02143 m
.00375 .02143 L
s
0 .03571 m
.00375 .03571 L
s
0 .05 m
.00375 .05 L
s
0 .07857 m
.00375 .07857 L
s
0 .09286 m
.00375 .09286 L
s
0 .10714 m
.00375 .10714 L
s
0 .13571 m
.00375 .13571 L
s
0 .15 m
.00375 .15 L
s
0 .16429 m
.00375 .16429 L
s
0 .19286 m
.00375 .19286 L
s
0 .20714 m
.00375 .20714 L
s
0 .22143 m
.00375 .22143 L
s
0 .25 m
.00375 .25 L
s
0 .26429 m
.00375 .26429 L
s
0 .27857 m
.00375 .27857 L
s
.25 Mabswid
0 0 m
0 .3 L
s
.02381 .29375 m
.02381 .3 L
s
.18254 .29375 m
.18254 .3 L
s
.34127 .29375 m
.34127 .3 L
s
.5 .29375 m
.5 .3 L
s
.65873 .29375 m
.65873 .3 L
s
.81746 .29375 m
.81746 .3 L
s
.97619 .29375 m
.97619 .3 L
s
.125 Mabswid
.05556 .29625 m
.05556 .3 L
s
.0873 .29625 m
.0873 .3 L
s
.11905 .29625 m
.11905 .3 L
s
.15079 .29625 m
.15079 .3 L
s
.21429 .29625 m
.21429 .3 L
s
.24603 .29625 m
.24603 .3 L
s
.27778 .29625 m
.27778 .3 L
s
.30952 .29625 m
.30952 .3 L
s
.37302 .29625 m
.37302 .3 L
s
.40476 .29625 m
.40476 .3 L
s
.43651 .29625 m
.43651 .3 L
s
.46825 .29625 m
.46825 .3 L
s
.53175 .29625 m
.53175 .3 L
s
.56349 .29625 m
.56349 .3 L
s
.59524 .29625 m
.59524 .3 L
s
.62698 .29625 m
.62698 .3 L
s
.69048 .29625 m
.69048 .3 L
s
.72222 .29625 m
.72222 .3 L
s
.75397 .29625 m
.75397 .3 L
s
.78571 .29625 m
.78571 .3 L
s
.84921 .29625 m
.84921 .3 L
s
.88095 .29625 m
.88095 .3 L
s
.9127 .29625 m
.9127 .3 L
s
.94444 .29625 m
.94444 .3 L
s
.25 Mabswid
0 .3 m
1 .3 L
s
.99375 .00714 m
1 .00714 L
s
.99375 .06429 m
1 .06429 L
s
.99375 .12143 m
1 .12143 L
s
.99375 .17857 m
1 .17857 L
s
.99375 .23571 m
1 .23571 L
s
.99375 .29286 m
1 .29286 L
s
.125 Mabswid
.99625 .02143 m
1 .02143 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05 m
1 .05 L
s
.99625 .07857 m
1 .07857 L
s
.99625 .09286 m
1 .09286 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .13571 m
1 .13571 L
s
.99625 .15 m
1 .15 L
s
.99625 .16429 m
1 .16429 L
s
.99625 .19286 m
1 .19286 L
s
.99625 .20714 m
1 .20714 L
s
.99625 .22143 m
1 .22143 L
s
.99625 .25 m
1 .25 L
s
.99625 .26429 m
1 .26429 L
s
.99625 .27857 m
1 .27857 L
s
.25 Mabswid
1 0 m
1 .3 L
s
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
.5 Mabswid
.02698 .11167 m
.03016 .10098 L
.03333 .1117 L
.03651 .15695 L
.03968 .1798 L
.04286 .18832 L
.04603 .18552 L
.04921 .2088 L
.05238 .21879 L
.05556 .21903 L
.05873 .20958 L
.0619 .18712 L
.06508 .19047 L
.06825 .18265 L
.07143 .19935 L
.0746 .20403 L
.07778 .19832 L
.08095 .18023 L
.08413 .18694 L
.0873 .18236 L
.09048 .16485 L
.09365 .12825 L
.09683 .12241 L
.1 .14015 L
.10317 .20323 L
.10635 .23817 L
.10952 .25731 L
.1127 .26741 L
.11587 .27204 L
.11905 .27283 L
.12222 .27007 L
.1254 .26277 L
.12857 .27294 L
.13175 .27829 L
.13492 .28073 L
.1381 .28111 L
.14127 .27957 L
.14444 .27557 L
.14762 .2677 L
.15079 .2762 L
.15397 .28077 L
.15714 .28301 L
.16032 .28373 L
.16349 .28316 L
.16667 .28112 L
.16984 .27688 L
.17302 .26894 L
.17619 .2545 L
.17937 .2595 L
.18254 .25892 L
Mistroke
.18571 .25253 L
.18889 .23808 L
.19206 .21047 L
.19524 .15995 L
.19841 .06869 L
.20159 .03747 L
.20476 .02806 L
.20794 .02894 L
.21111 .0412 L
.21429 .04199 L
.21746 .03159 L
.22063 .03257 L
.22381 .04615 L
.22698 .04769 L
.23016 .06614 L
.23333 .07063 L
.23651 .09855 L
.23968 .1094 L
.24286 .15474 L
.24603 .1776 L
.24921 .18605 L
.25238 .18309 L
.25556 .16766 L
.25873 .17667 L
.2619 .17384 L
.26508 .15815 L
.26825 .16687 L
.27143 .1634 L
.2746 .18583 L
.27778 .19426 L
.28095 .19166 L
.28413 .21509 L
.2873 .22549 L
.29048 .22652 L
.29365 .25375 L
.29683 .26891 L
.3 .27733 L
.30317 .28201 L
.30635 .28458 L
.30952 .28597 L
.3127 .28665 L
.31587 .28687 L
.31905 .2867 L
.32222 .28609 L
.3254 .28482 L
.32857 .28244 L
.33175 .27811 L
.33492 .27031 L
.3381 .25628 L
.34127 .23105 L
Mistroke
.34444 .23095 L
.34762 .25582 L
.35079 .2696 L
.35397 .27715 L
.35714 .28113 L
.36032 .28296 L
.36349 .28328 L
.36667 .28221 L
.36984 .27935 L
.37302 .27372 L
.37619 .26331 L
.37937 .24444 L
.38254 .24737 L
.38571 .24338 L
.38889 .23107 L
.39206 .20607 L
.39524 .15957 L
.39841 .14949 L
.40159 .16349 L
.40476 .2187 L
.40794 .24943 L
.41111 .26654 L
.41429 .27606 L
.41746 .28136 L
.42063 .28431 L
.42381 .28595 L
.42698 .28687 L
.43016 .28737 L
.43333 .28765 L
.43651 .28781 L
.43968 .28789 L
.44286 .28792 L
.44603 .28793 L
.44921 .2879 L
.45238 .28783 L
.45556 .28769 L
.45873 .28745 L
.4619 .287 L
.46508 .28619 L
.46825 .28474 L
.47143 .28213 L
.4746 .27744 L
.47778 .26901 L
.48095 .25388 L
.48413 .22669 L
.4873 .17784 L
.49048 .16679 L
.49365 .13984 L
.49683 .13987 L
.5 .16689 L
Mistroke
.50317 .178 L
.50635 .17711 L
.50952 .16392 L
.5127 .17497 L
.51587 .22382 L
.51905 .25089 L
.52222 .26576 L
.5254 .27368 L
.52857 .27744 L
.53175 .27837 L
.53492 .27679 L
.5381 .27216 L
.54127 .26283 L
.54444 .2709 L
.54762 .27439 L
.55079 .27455 L
.55397 .27141 L
.55714 .26389 L
.56032 .24931 L
.56349 .25487 L
.56667 .25425 L
.56984 .24722 L
.57302 .23131 L
.57619 .23759 L
.57937 .23591 L
.58254 .22568 L
.58571 .20328 L
.58889 .16081 L
.59206 .08328 L
.59524 .05789 L
.59841 .05357 L
.60159 .0359 L
.60476 .03303 L
.60794 .01879 L
.61111 .01448 L
.61429 .01481 L
.61746 .02019 L
.62063 .03721 L
.62381 .0867 L
.62698 .11138 L
.63016 .18967 L
.63333 .23324 L
.63651 .2575 L
.63968 .27099 L
.64286 .2785 L
.64603 .28266 L
.64921 .28495 L
.65238 .28617 L
.65556 .28677 L
.65873 .28694 L
Mistroke
.6619 .28675 L
.66508 .28613 L
.66825 .28487 L
.67143 .28251 L
.6746 .27823 L
.67778 .27052 L
.68095 .25664 L
.68413 .23171 L
.6873 .18691 L
.69048 .10642 L
.69365 .08071 L
.69683 .07833 L
.7 .06225 L
.70317 .06423 L
.70635 .08668 L
.70952 .15709 L
.7127 .19526 L
.71587 .21466 L
.71905 .22214 L
.72222 .22035 L
.7254 .24349 L
.72857 .2553 L
.73175 .25996 L
.73492 .2591 L
.7381 .25243 L
.74127 .23759 L
.74444 .20935 L
.74762 .20843 L
.75079 .19691 L
.75397 .17071 L
.75714 .17167 L
.76032 .16038 L
.76349 .13286 L
.76667 .07939 L
.76984 .06351 L
.77302 .0658 L
.77619 .05571 L
.77937 .06156 L
.78254 .09052 L
.78571 .17802 L
.78889 .22673 L
.79206 .25384 L
.79524 .26892 L
.79841 .27729 L
.80159 .28193 L
.80476 .28445 L
.80794 .28576 L
.81111 .28631 L
.81429 .2863 L
.81746 .28572 L
Mistroke
.82063 .28438 L
.82381 .28179 L
.82698 .27705 L
.83016 .26848 L
.83333 .27612 L
.83651 .28001 L
.83968 .28155 L
.84286 .28126 L
.84603 .27905 L
.84921 .27413 L
.85238 .26478 L
.85556 .27244 L
.85873 .27583 L
.8619 .27613 L
.86508 .27346 L
.86825 .26688 L
.87143 .25405 L
.8746 .26041 L
.87778 .26115 L
.88095 .25653 L
.88413 .24493 L
.8873 .25356 L
.89048 .25548 L
.89365 .25138 L
.89683 .26755 L
.9 .27654 L
.90317 .28151 L
.90635 .28422 L
.90952 .28564 L
.9127 .28627 L
.91587 .28632 L
.91905 .28581 L
.92222 .28457 L
.9254 .28215 L
.92857 .27771 L
.93175 .26967 L
.93492 .25519 L
.9381 .22916 L
.94127 .22868 L
.94444 .2192 L
.94762 .19737 L
.95079 .15549 L
.95397 .14758 L
.95714 .16397 L
.96032 .16707 L
.96349 .15797 L
.96667 .17322 L
.96984 .17567 L
.97302 .16621 L
.97619 .18113 L
Mistroke
Mfstroke
.9 g
.0873 .00714 m
.0873 .29286 L
.09365 .29286 L
.09365 .00714 L
F
.19524 .00714 m
.19524 .29286 L
.23968 .29286 L
.23968 .00714 L
F
.2746 .00714 m
.2746 .29286 L
.29365 .29286 L
.29365 .00714 L
F
.4873 .00714 m
.4873 .29286 L
.49683 .29286 L
.49683 .00714 L
F
.58254 .00714 m
.58254 .29286 L
.61746 .29286 L
.61746 .00714 L
F
.69365 .00714 m
.69365 .29286 L
.72222 .29286 L
.72222 .00714 L
F
.76032 .00714 m
.76032 .29286 L
.78254 .29286 L
.78254 .00714 L
F
.94762 .00714 m
.94762 .29286 L
.95714 .29286 L
.95714 .00714 L
F
.97302 .00714 m
.97302 .29286 L
.97619 .29286 L
.97619 .00714 L
F
0 g
.02698 .11167 m
.03016 .10098 L
.03333 .1117 L
.03651 .15695 L
.03968 .1798 L
.04286 .18832 L
.04603 .18552 L
.04921 .2088 L
.05238 .21879 L
.05556 .21903 L
.05873 .20958 L
.0619 .18712 L
.06508 .19047 L
.06825 .18265 L
.07143 .19935 L
.0746 .20403 L
.07778 .19832 L
.08095 .18023 L
.08413 .18694 L
.0873 .18236 L
.09048 .16485 L
.09365 .12825 L
.09683 .12241 L
.1 .14015 L
.10317 .20323 L
.10635 .23817 L
.10952 .25731 L
.1127 .26741 L
.11587 .27204 L
.11905 .27283 L
.12222 .27007 L
.1254 .26277 L
.12857 .27294 L
.13175 .27829 L
.13492 .28073 L
.1381 .28111 L
.14127 .27957 L
.14444 .27557 L
.14762 .2677 L
.15079 .2762 L
.15397 .28077 L
.15714 .28301 L
.16032 .28373 L
.16349 .28316 L
.16667 .28112 L
.16984 .27688 L
.17302 .26894 L
.17619 .2545 L
.17937 .2595 L
.18254 .25892 L
Mistroke
.18571 .25253 L
.18889 .23808 L
.19206 .21047 L
.19524 .15995 L
.19841 .06869 L
.20159 .03747 L
.20476 .02806 L
.20794 .02894 L
.21111 .0412 L
.21429 .04199 L
.21746 .03159 L
.22063 .03257 L
.22381 .04615 L
.22698 .04769 L
.23016 .06614 L
.23333 .07063 L
.23651 .09855 L
.23968 .1094 L
.24286 .15474 L
.24603 .1776 L
.24921 .18605 L
.25238 .18309 L
.25556 .16766 L
.25873 .17667 L
.2619 .17384 L
.26508 .15815 L
.26825 .16687 L
.27143 .1634 L
.2746 .18583 L
.27778 .19426 L
.28095 .19166 L
.28413 .21509 L
.2873 .22549 L
.29048 .22652 L
.29365 .25375 L
.29683 .26891 L
.3 .27733 L
.30317 .28201 L
.30635 .28458 L
.30952 .28597 L
.3127 .28665 L
.31587 .28687 L
.31905 .2867 L
.32222 .28609 L
.3254 .28482 L
.32857 .28244 L
.33175 .27811 L
.33492 .27031 L
.3381 .25628 L
.34127 .23105 L
Mistroke
.34444 .23095 L
.34762 .25582 L
.35079 .2696 L
.35397 .27715 L
.35714 .28113 L
.36032 .28296 L
.36349 .28328 L
.36667 .28221 L
.36984 .27935 L
.37302 .27372 L
.37619 .26331 L
.37937 .24444 L
.38254 .24737 L
.38571 .24338 L
.38889 .23107 L
.39206 .20607 L
.39524 .15957 L
.39841 .14949 L
.40159 .16349 L
.40476 .2187 L
.40794 .24943 L
.41111 .26654 L
.41429 .27606 L
.41746 .28136 L
.42063 .28431 L
.42381 .28595 L
.42698 .28687 L
.43016 .28737 L
.43333 .28765 L
.43651 .28781 L
.43968 .28789 L
.44286 .28792 L
.44603 .28793 L
.44921 .2879 L
.45238 .28783 L
.45556 .28769 L
.45873 .28745 L
.4619 .287 L
.46508 .28619 L
.46825 .28474 L
.47143 .28213 L
.4746 .27744 L
.47778 .26901 L
.48095 .25388 L
.48413 .22669 L
.4873 .17784 L
.49048 .16679 L
.49365 .13984 L
.49683 .13987 L
.5 .16689 L
Mistroke
.50317 .178 L
.50635 .17711 L
.50952 .16392 L
.5127 .17497 L
.51587 .22382 L
.51905 .25089 L
.52222 .26576 L
.5254 .27368 L
.52857 .27744 L
.53175 .27837 L
.53492 .27679 L
.5381 .27216 L
.54127 .26283 L
.54444 .2709 L
.54762 .27439 L
.55079 .27455 L
.55397 .27141 L
.55714 .26389 L
.56032 .24931 L
.56349 .25487 L
.56667 .25425 L
.56984 .24722 L
.57302 .23131 L
.57619 .23759 L
.57937 .23591 L
.58254 .22568 L
.58571 .20328 L
.58889 .16081 L
.59206 .08328 L
.59524 .05789 L
.59841 .05357 L
.60159 .0359 L
.60476 .03303 L
.60794 .01879 L
.61111 .01448 L
.61429 .01481 L
.61746 .02019 L
.62063 .03721 L
.62381 .0867 L
.62698 .11138 L
.63016 .18967 L
.63333 .23324 L
.63651 .2575 L
.63968 .27099 L
.64286 .2785 L
.64603 .28266 L
.64921 .28495 L
.65238 .28617 L
.65556 .28677 L
.65873 .28694 L
Mistroke
.6619 .28675 L
.66508 .28613 L
.66825 .28487 L
.67143 .28251 L
.6746 .27823 L
.67778 .27052 L
.68095 .25664 L
.68413 .23171 L
.6873 .18691 L
.69048 .10642 L
.69365 .08071 L
.69683 .07833 L
.7 .06225 L
.70317 .06423 L
.70635 .08668 L
.70952 .15709 L
.7127 .19526 L
.71587 .21466 L
.71905 .22214 L
.72222 .22035 L
.7254 .24349 L
.72857 .2553 L
.73175 .25996 L
.73492 .2591 L
.7381 .25243 L
.74127 .23759 L
.74444 .20935 L
.74762 .20843 L
.75079 .19691 L
.75397 .17071 L
.75714 .17167 L
.76032 .16038 L
.76349 .13286 L
.76667 .07939 L
.76984 .06351 L
.77302 .0658 L
.77619 .05571 L
.77937 .06156 L
.78254 .09052 L
.78571 .17802 L
.78889 .22673 L
.79206 .25384 L
.79524 .26892 L
.79841 .27729 L
.80159 .28193 L
.80476 .28445 L
.80794 .28576 L
.81111 .28631 L
.81429 .2863 L
.81746 .28572 L
Mistroke
.82063 .28438 L
.82381 .28179 L
.82698 .27705 L
.83016 .26848 L
.83333 .27612 L
.83651 .28001 L
.83968 .28155 L
.84286 .28126 L
.84603 .27905 L
.84921 .27413 L
.85238 .26478 L
.85556 .27244 L
.85873 .27583 L
.8619 .27613 L
.86508 .27346 L
.86825 .26688 L
.87143 .25405 L
.8746 .26041 L
.87778 .26115 L
.88095 .25653 L
.88413 .24493 L
.8873 .25356 L
.89048 .25548 L
.89365 .25138 L
.89683 .26755 L
.9 .27654 L
.90317 .28151 L
.90635 .28422 L
.90952 .28564 L
.9127 .28627 L
.91587 .28632 L
.91905 .28581 L
.92222 .28457 L
.9254 .28215 L
.92857 .27771 L
.93175 .26967 L
.93492 .25519 L
.9381 .22916 L
.94127 .22868 L
.94444 .2192 L
.94762 .19737 L
.95079 .15549 L
.95397 .14758 L
.95714 .16397 L
.96032 .16707 L
.96349 .15797 L
.96667 .17322 L
.96984 .17567 L
.97302 .16621 L
.97619 .18113 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 86.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000ER000`400?l00000o`00003oo`3ooolQ
0?ooo`009`3oool200000200oooo0P0000040?ooo`8000006@3oool500000080oooo0P0000040?oo
o`8000005`3oool500000080oooo0P0000040?ooo`8000005P3oool4000000<0oooo0P0000040?oo
o`8000005P3oool4000000<0oooo0P0000040?ooo`800000603oool2000000@0oooo0P0000040?oo
o`8000004@3oool002H0oooo00@000000?ooo`3oool000007P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000F0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000@0?ooo`009P3oool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo000V
0?ooo`040000003oool0oooo000001l0oooo0P0000030?ooo`040000003oool0oooo000001X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`00000G
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool0
00006@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool03P3oool002H0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000001X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000005@3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000005@3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000005P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
403oool002L0oooo0P00000P0?ooo`<000000`3oool2000001X0oooo0P0000040?ooo`800000103o
ool2000001P0oooo0P0000040?ooo`<000000`3oool2000001L0oooo0P0000040?ooo`800000103o
ool2000001L0oooo0P0000040?ooo`<000000`3oool2000001P0oooo0P0000040?ooo`800000103o
ool200000140oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo000K0?ooo`8000001@3oooo/00000180oooo000J0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo000J0?ooo`040000003oool0oooo000000@0oooo0`0000030?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0
oooo0?ooo`8000004P3oool001X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0B0?ooo`030>KViP3oool0oooo01H0oooo2`3Vi^H80?ooo`@0i^KV;P3oool20>KViQ@0oooo1`3V
i^H00`000000oooo0?ooo`0@0?ooo`L0i^KV2@3oool50>KViRL0oooo0P3Vi^H40?ooo`030>KViP3o
ool0oooo00<0oooo00<000000?ooo`3oool0403oool001X0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0B0?ooo`030>KViP3oool0oooo01H0oooo2`3Vi^H80?ooo`@0i^KV;P3o
ool20>KViQ@0oooo1P3Vi^H00`000000i^KV0000000A0?ooo`L0i^KV2@3oool50>KViRL0oooo0P3V
i^H40?ooo`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool001/0oooo0P000005
0?ooo`8000004`3oool00`3Vi^H0oooo0?ooo`0F0?ooo`/0i^KV203oool40>KViRh0oooo0P3Vi^HD
0?ooo`H0i^KV00<000000>KViP0000004@3oool70>KViPT0oooo1@3Vi^HW0?ooo`80i^KV103oool0
0`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
0180oooo00<0i^KV0?ooo`3oool05P3oool;0>KViPP0oooo103Vi^H^0?ooo`80i^KV503oool50>KV
iP040000003Vi^H0i^KV00000140oooo1`3Vi^H90?ooo`D0i^KV9`3oool20>KViP@0oooo00<0i^KV
0?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`0B0?oo
o`030>KViP3oool0oooo01H0oooo0P3Vi^H2000000L0i^KV203oool40>KViRh0oooo0P3Vi^HD0?oo
o`D0i^KV00@000000>KViP3Vi^H000004@3oool70>KViPT0oooo1@3Vi^HW0?ooo`80i^KV103oool0
0`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000R0?ooo`8000004`3oool00`3V
i^H0oooo0?ooo`0F0?ooo`80i^KV0P0000000`3Vi^H00000000000040>KViPP0oooo103Vi^H^0?oo
o`80i^KV503oool50>KViP050000003Vi^H0i^KV0?ooo`000000403oool70>KViPT0oooo1@3Vi^HW
0?ooo`80i^KV103oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo0180oooo00<0i^KV0?ooo`3oool05P3oool20>KViP030000003Vi^H00000
00800000103Vi^H80?ooo`@0i^KV;P3oool20>KViQ@0oooo1@3Vi^H01@000000i^KV0>KViP3oool0
00000100oooo1`3Vi^H90?ooo`D0i^KV9`3oool20>KViP@0oooo00<0i^KV0?ooo`3oool00`3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`0B0?ooo`030>KViP3oool0oooo
01H0oooo0P3Vi^H01P000000i^KV000000000000i^KV000000<0i^KV203oool40>KViRh0oooo0P3V
i^HD0?ooo`D0i^KV00D000000>KViP3Vi^H0oooo0000000@0?ooo`L0i^KV2@3oool50>KViRL0oooo
0P3Vi^H40?ooo`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool04P3oool00`3Vi^H0oooo0?ooo`0F0?ooo`80i^KV00<000000>KViP3Vi^H00P3V
i^H200000080i^KV203oool40>KViRh0oooo0P3Vi^HD0?ooo`@0i^KV00H000000>KViP3Vi^H0i^KV
0?ooo`00000@0?ooo`L0i^KV2@3oool50>KViRL0oooo0P3Vi^H40?ooo`030>KViP3oool0oooo00<0
oooo00<000000?ooo`3oool0403oool00280oooo0P00000C0?ooo`030>KViP3oool0oooo01H0oooo
0P3Vi^H00`000000i^KV0>KViP030>KViP030000003Vi^H0i^KV00P0oooo103Vi^H^0?ooo`80i^KV
503oool40>KViP060000003Vi^H0i^KV0>KViP3oool00000403oool70>KViPT0oooo1@3Vi^HW0?oo
o`80i^KV103oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000?0?ooo`80
0000103oool2000000<0oooo100000040?ooo`030000003oool0oooo0180oooo00<0i^KV0?ooo`3o
ool05P3oool00`3Vi^H000000>KViP050>KViP030000003Vi^H0i^KV00P0oooo103Vi^H^0?ooo`80
i^KV503oool40>KViP060000003Vi^H0i^KV0>KViP3oool00000403oool70>KViPT0oooo103Vi^H0
0`000000oooo0?ooo`0U0?ooo`80i^KV103oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0
oooo0100oooo000>0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0B0?ooo`030>KViP3oool0oooo01H0oooo00<0i^KV0000003Vi^H01@3Vi^H0
0`000000i^KV0>KViP080?ooo`@0i^KV;P3oool20>KViQ@0oooo0`3Vi^H00`000000i^KV0>KViP02
0>KViP030?ooo`000000oooo00l0oooo1`3Vi^H90?ooo`@0i^KV00<000000?ooo`3oool09@3oool2
0>KViP@0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`003P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo0`00000B0?ooo`030>KViP3oool0
oooo01H0oooo00<0i^KV0000003Vi^H01@3Vi^H00`000000i^KV0>KViP080?ooo`@0i^KV;P3oool2
0>KViQ@0oooo0`3Vi^H00`000000i^KV0>KViP020>KViP80oooo00<000000?ooo`3oool03@3oool2
0>KViP8000000`3Vi^H90?ooo`80i^KV0P0000000`3Vi^H000000?ooo`0U0?ooo`80i^KV103oool0
0`3Vi^H0oooo0?ooo`020?ooo`8000004P3oool000h0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<0i^KV0?ooo`3oool05P3oool0
0`3Vi^H000000>KViP050>KViP030000003Vi^H0i^KV00P0oooo103Vi^H^0?ooo`80i^KV503oool3
0>KViP030000003Vi^H0i^KV0080i^KV0P3oool00`000000oooo0?ooo`0=0?ooo`80i^KV0P000003
0>KViPT0oooo0P3Vi^H2000000030>KViP000000oooo02D0oooo0P3Vi^H40?ooo`030>KViP3oool0
oooo00<0oooo00<000000?ooo`3oool0403oool000h0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00<0i^KV0?ooo`3oool05P3o
ool00`3Vi^H000000>KViP060>KViP030000003Vi^H0oooo00L0oooo103Vi^H^0?ooo`80i^KV503o
ool20>KViP030000003Vi^H0i^KV00<0i^KV0P3oool00`000000oooo0?ooo`0=0?ooo`040>KViP00
0000i^KV000000<0i^KV2@3oool20>KViP040000003Vi^H0i^KV000002H0oooo0P3Vi^H40?ooo`03
0>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool000l0oooo0P00000:0?ooo`800000
1@3oool00`000000oooo0?ooo`0B0?ooo`030>KViP3oool0oooo01H0oooo00<0i^KV0000003Vi^H0
1P3Vi^H00`000000i^KV0?ooo`070?ooo`@0i^KV;P3oool20>KViQ@0oooo0P3Vi^H00`000000i^KV
0>KViP030>KViP80oooo00<000000?ooo`3oool03@3oool0103Vi^H000000>KViP0000030>KViPT0
oooo0P3Vi^H010000000i^KV0>KViP00000V0?ooo`80i^KV103oool00`3Vi^H0oooo0?ooo`030?oo
o`030000003oool0oooo0100oooo000R0?ooo`8000004`3oool00`3Vi^H0oooo0?ooo`0F0?ooo`03
0>KViP000000i^KV00H0i^KV00<000000>KViP3oool01`3oool40>KViRh0oooo0P3Vi^HD0?ooo`80
i^KV00<000000>KViP3Vi^H00`3Vi^H20?ooo`030000003oool0oooo00d0oooo0P0000000`3Vi^H0
00000>KViP020>KViPT0oooo0P3Vi^H010000000i^KV0>KViP00000V0?ooo`80i^KV103oool00`3V
i^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo0180
oooo00<0i^KV0?ooo`3oool05P3oool00`3Vi^H000000>KViP060>KViP030000003Vi^H0oooo00L0
oooo103Vi^H^0?ooo`80i^KV503oool20>KViP030000003Vi^H0i^KV00<0i^KV0P3oool00`000000
oooo0?ooo`0=0?ooo`040000003Vi^H0i^KV000000<0i^KV2@3oool20>KViP040000003Vi^H0i^KV
000002H0oooo0P3Vi^H40?ooo`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool04P3oool00`3Vi^H0oooo0?ooo`0F0?ooo`030>KViP000000i^KV
00L0i^KV00<000000?ooo`3oool01P3oool40>KViRh0oooo0P3Vi^HD0?ooo`80i^KV00<000000>KV
iP3Vi^H00`3Vi^H20?ooo`030000003oool0oooo00d0oooo00@000000>KViP3Vi^H000000`3Vi^H9
0?ooo`80i^KV00@000000>KViP3Vi^H000009P3oool20>KViP@0oooo00<0i^KV0?ooo`3oool00`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool2000001<0oooo00<0i^KV0?ooo`3oool05P3oool0
0`3Vi^H000000>KViP070>KViP030000003oool0oooo00H0oooo103Vi^H^0?ooo`80i^KV503oool2
0>KViP030000003Vi^H0i^KV00<0i^KV0P3oool00`000000oooo0?ooo`0=0?ooo`040000003Vi^H0
i^KV000000<0i^KV2@3oool20>KViP040000003Vi^H0i^KV000002H0oooo0P3Vi^H40?ooo`030>KV
iP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool04P3o
ool00`3Vi^H0oooo0?ooo`0F0?ooo`030>KViP000000i^KV00L0i^KV00<000000?ooo`3oool01P3o
ool40>KViRh0oooo0P3Vi^HD0?ooo`80i^KV00<000000>KViP3Vi^H00`3Vi^H20?ooo`030000003o
ool0oooo00d0oooo00@000000>KViP3Vi^H000000`3Vi^H90?ooo`80i^KV00@000000>KViP3Vi^H0
00009P3oool20>KViP@0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<0i^KV0?ooo`3oool0
5P3oool00`3Vi^H000000>KViP070>KViP030000003oool0oooo00H0oooo103Vi^H^0?ooo`80i^KV
503oool20>KViP030000003Vi^H0i^KV00<0i^KV0`3oool00`000000oooo0?ooo`0<0?ooo`040000
003Vi^H0i^KV000000<0i^KV2@3oool20>KViP040000003Vi^H0i^KV000002H0oooo0P3Vi^H40?oo
o`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool00280oooo0P0000040?ooo`80
00003@3oool00`3Vi^H0oooo0?ooo`0F0?ooo`030>KViP000000i^KV00P0i^KV00<000000?ooo`3o
ool01@3oool40>KViRh0oooo0P3Vi^HD0?ooo`80i^KV00<000000>KViP3Vi^H00`3Vi^H30?ooo`03
0000003oool0oooo00`0oooo00@000000>KViP3Vi^H000000`3Vi^H90?ooo`030>KViP000000i^KV
0080i^KV00<000000?ooo`3oool0903oool20>KViP@0oooo00<0i^KV0?ooo`3oool00`3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000`0
oooo00<0i^KV0?ooo`3oool05P3oool00`3Vi^H000000>KViP080>KViP030000003oool0oooo00D0
oooo103Vi^H^0?ooo`80i^KV503oool20>KViP030000003Vi^H0i^KV00<0i^KV0`3oool00`000000
oooo0?ooo`0<0?ooo`040000003Vi^H0i^KV000000<0i^KV2@3oool00`3Vi^H000000>KViP020>KV
iP030000003oool0oooo02@0oooo0P3Vi^H40?ooo`030>KViP3oool0oooo00<0oooo00<000000?oo
o`3oool0403oool000l0oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0:0?ooo`030>KViP3oool0oooo01H0oooo00<000000>KViP3V
i^H0203Vi^H00`000000oooo0?ooo`050?ooo`@0i^KV;P3oool20>KViQ@0oooo0P3Vi^H00`000000
i^KV0>KViP030>KViP<0oooo00<000000?ooo`3oool0303oool010000000i^KV0>KViP0000030>KV
iPT0oooo00<0i^KV0000003Vi^H00P3Vi^H00`000000oooo0?ooo`0T0?ooo`80i^KV103oool00`3V
i^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000>0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00X0oooo00<0i^KV0?ooo`3oool05P3oool00`000000i^KV0>KViP080>KViP030000003oool0oooo
00D0oooo103Vi^H^0?ooo`80i^KV503oool20>KViP030000003Vi^H0i^KV00<0i^KV0`3oool00`00
0000oooo0?ooo`0<0?ooo`040000003Vi^H0i^KV000000<0i^KV2@3oool00`3Vi^H000000>KViP02
0>KViP030000003oool0oooo02@0oooo0P3Vi^H40?ooo`030>KViP3oool0oooo00<0oooo00<00000
0?ooo`3oool0403oool000h0oooo00@000000?ooo`3oool00000203oool5000000<0oooo0`000005
0?ooo`030000003oool0oooo00X0oooo00<0i^KV0?ooo`0000005P3oool00`000000i^KV0>KViP08
0>KViP030000003oool0oooo00D0oooo103Vi^H^0?ooo`80i^KV503oool20>KViP030000003Vi^H0
i^KV00<0i^KV0`3oool00`000000oooo0?ooo`0<0?ooo`050000003Vi^H0i^KV0>KViP0000000P3V
i^H90?ooo`030>KViP000000i^KV0080i^KV00<000000?ooo`3oool0903oool20>KViP@0oooo00<0
i^KV0?ooo`3oool00P3oool200000180oooo000>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
00<0i^KV0000000000005P3oool00`000000i^KV0>KViP080>KViP030000003oool0oooo00D0oooo
103Vi^H^0?ooo`80i^KV503oool20>KViP030000003Vi^H0i^KV00<0i^KV0`3oool00`000000oooo
0?ooo`0<0?ooo`050000003Vi^H0i^KV0>KViP0000000P3Vi^H90?ooo`030>KViP000000i^KV0080
i^KV00<000000?ooo`3oool0903oool20>KViP@0oooo00<0i^KV0?ooo`3oool00`3oool00`000000
oooo0?ooo`0@0?ooo`003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030>KViP000000000001H0
oooo00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`050?ooo`@0i^KV;P3oool20>KViQ@0
oooo0P3Vi^H00`000000i^KV0>KViP030>KViP<0oooo00<000000?ooo`3oool0303oool01@000000
i^KV0>KViP3Vi^H000000080i^KV2@3oool00`3Vi^H000000>KViP020>KViP030000003oool0oooo
02@0oooo0P3Vi^H40?ooo`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool000l0
oooo0P00000;0?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool02@3oool0103Vi^H0
00000?ooo`00000E0?ooo`030000003Vi^H0i^KV00P0i^KV00<000000?ooo`3oool01@3oool40>KV
iRh0oooo0P3Vi^HD0?ooo`80i^KV00<000000>KViP3Vi^H00`3Vi^H30?ooo`030000003oool0oooo
00`0oooo00D000000>KViP3Vi^H0i^KV000000020>KViPT0oooo00<0i^KV0000003Vi^H00P3Vi^H0
0`3oool000000?ooo`0T0?ooo`80i^KV103oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0103V
i^H000000?ooo`00000E0?ooo`030000003Vi^H0i^KV00P0i^KV00<000000?ooo`3oool01@3oool4
0>KViRh0oooo00<0i^KV0000000000004`3oool20>KViP030000003Vi^H0i^KV00<0i^KV0`3oool0
0`000000oooo0?ooo`0<0?ooo`050000003Vi^H0i^KV0>KViP0000000P3Vi^H90?ooo`030>KViP00
0000i^KV0080i^KV00<0oooo0000003oool0903oool20>KViP@0oooo00<0i^KV0?ooo`3oool00`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00@0i^KV0000003oool000005@3oool00`000000i^KV0>KViP080>KViP030000003o
ool0oooo00D0oooo103Vi^H^0?ooo`030>KViP000000000001<0oooo0P3Vi^H00`000000i^KV0>KV
iP030>KViP<0oooo00<000000?ooo`3oool0303oool01@000000i^KV0>KViP3Vi^H000000080i^KV
2@3oool00`3Vi^H000000>KViP020>KViP030?ooo`000000oooo02@0oooo0P3Vi^H40?ooo`030>KV
iP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool00280oooo0P0000070?ooo`030000003o
ool0oooo00T0oooo00@000000?ooo`3oool000005@3oool00`000000i^KV0>KViP080>KViP030000
003oool0oooo00D0oooo103Vi^HI0?ooo`030000003oool0oooo0180oooo00<0i^KV000000000000
4`3oool20>KViP030000003Vi^H0i^KV00<0i^KV0`3oool00`000000oooo0?ooo`0;0?ooo`030000
003Vi^H0i^KV0080i^KV00<000000>KViP3Vi^H02@3oool00`000000i^KV0>KViP020>KViP030?oo
o`000000oooo02@0oooo0P3Vi^H01@000000oooo0?ooo`3oool0i^KV00D0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`040000
003oool0oooo000001D0oooo00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`050?ooo`@0
i^KV6@3oool00`000000oooo0?ooo`0B0?ooo`030>KViP000000000001<0oooo0P3Vi^H00`000000
i^KV0>KViP030>KViP<0oooo00<000000?ooo`3oool02`3oool00`000000i^KV0>KViP020>KViP03
0000003Vi^H0i^KV00T0oooo00<000000>KViP3Vi^H00P3Vi^H00`3oool000000?ooo`0T0?ooo`03
0>KViP000000000000<0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0
00005@3oool00`000000i^KV0>KViP080>KViP030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103Vi^HH0?ooo`800000503oool0103Vi^H000000?ooo`00000B0?ooo`80i^KV00<000000>KV
iP3Vi^H00`3Vi^H30?ooo`030000003oool0oooo00/0oooo00<000000>KViP3Vi^H00P3Vi^H00`00
0000i^KV0>KViP090?ooo`030000003Vi^H0i^KV0080i^KV00<0oooo0000003oool0903oool01`3V
i^H000000000003oool000000?ooo`3Vi^H01@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000005@3o
ool00`000000i^KV0>KViP080>KViP030000003oool0oooo0080oooo00<000000?ooo`3oool0103V
i^HH0?ooo`030000003oool0000001<0oooo00@0i^KV0000003oool000004P3oool20>KViP030000
003Vi^H0i^KV00<0i^KV0`3oool00`000000oooo0?ooo`0;0?ooo`030000003Vi^H0i^KV0080i^KV
00<000000>KViP3Vi^H02@3oool00`000000i^KV0>KViP020>KViP030?ooo`000000oooo02@0oooo
00<0i^KV0000000000000P0000000`3oool0i^KV0?ooo`040?ooo`030000003oool0oooo0100oooo
000R0?ooo`8000001`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000001D0oooo
00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`020?ooo`<00000103Vi^HH0?ooo`030000
003oool0000001<0oooo00H0i^KV0000003oool000000?ooo`00000@0?ooo`80i^KV00<000000>KV
iP3Vi^H00`3Vi^H30?ooo`030000003oool0oooo00/0oooo00<000000>KViP3Vi^H00P3Vi^H00`00
0000i^KV0>KViP080?ooo`030000003Vi^H0i^KV00<0i^KV00<0oooo0000003oool0903oool00`3V
i^H0000000000002000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0403oool000l0
oooo0P0000040?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`090?ooo`040000003oool0oooo000001D0oooo00<000000>KViP3Vi^H0203Vi^H0203o
ool000000?ooo`000000oooo0000003oool00000103Vi^HH0?ooo`030000003oool0000001<0oooo
00H0i^KV0000003oool000000?ooo`00000@0?ooo`80i^KV00<000000>KViP3Vi^H00`3Vi^H30?oo
o`030000003oool0oooo00/0oooo00<000000>KViP3Vi^H00P3Vi^H00`000000i^KV0>KViP080?oo
o`030000003Vi^H0i^KV00<0i^KV00<0oooo0000003oool0903oool00`3Vi^H000000?ooo`020?oo
o`8000001@3oool00`000000oooo0?ooo`0@0?ooo`003P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`040000003oool0oooo000001D0oooo00<000000>KViP3Vi^H0203Vi^H0203oool000000?oo
o`000000oooo0000003oool00000103Vi^HH0?ooo`030000003oool0000001<0oooo00L000000>KV
iP3oool0oooo0000003oool0000000l0oooo0P3Vi^H00`000000i^KV0>KViP030>KViP<0oooo00<0
00000?ooo`3oool02`3oool00`000000i^KV0>KViP020>KViP030000003Vi^H0i^KV00P0oooo00<0
00000>KViP3Vi^H00`3Vi^H00`3oool000000?ooo`0T0?ooo`030>KViP000000oooo0080oooo0P00
00050?ooo`030000003oool0oooo0100oooo000>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool3000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
000000020?ooo`030000003oool0oooo01<0oooo00<000000>KViP3Vi^H0203Vi^H01@3oool00000
0000003oool0000000<0oooo00@000000>KViP3Vi^H0i^KV603oool00`000000oooo0000000C0?oo
o`070000003Vi^H0oooo0?ooo`000000oooo0000000?0?ooo`80i^KV00<000000>KViP3Vi^H00`3V
i^H30?ooo`030000003oool0oooo00/0oooo00<000000>KViP3Vi^H00`3Vi^H00`000000i^KV0?oo
o`070?ooo`030000003Vi^H0i^KV00<0i^KV00<0oooo0000003oool0903oool00`000000i^KV0?oo
o`030?ooo`030>KViP000000oooo0080oooo0P00000B0?ooo`003P3oool010000000oooo0?ooo`00
00080?ooo`<000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00H0
00000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo01<0oooo00<000000>KViP3V
i^H0203Vi^H00`3oool00000000000050?ooo`040000003Vi^H0i^KV0>KViQP0oooo00<000000?oo
o`0000004`3oool00`000000i^KV0?ooo`030?ooo`030000003oool0oooo00d0oooo00<0i^KV0000
003Vi^H01@3Vi^H30?ooo`030000003oool0oooo00/0oooo00<000000>KViP3Vi^H00`3Vi^H00`00
0000i^KV0?ooo`060?ooo`030000003oool0i^KV00@0i^KV00<0oooo0000003oool0903oool00`00
0000i^KV0?ooo`030?ooo`030>KViP000000oooo00<0oooo00<000000?ooo`3oool0403oool000h0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo0P0000030?ooo`8000000P3oool2000000040>KViP3oool0oooo000001@0oooo00<00000
0>KViP3Vi^H02@3Vi^H20?ooo`030000003oool0oooo00<0oooo00@000000>KViP3Vi^H0i^KV5`3o
ool010000000oooo0?ooo`00000C0?ooo`030000003Vi^H0oooo00<0oooo00<000000?ooo`3oool0
3@3oool00`3Vi^H000000>KViP050>KViP<0oooo00<000000?ooo`3oool02`3oool00`000000i^KV
0>KViP030>KViP030000003Vi^H0oooo00H0oooo00<000000?ooo`3Vi^H0103Vi^H00`3oool00000
0?ooo`0T0?ooo`030000003Vi^H0oooo00<0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo
0?ooo`0@0?ooo`003`3oool2000000X0oooo0`0000040?ooo`8000002@3oool010000000oooo0?oo
o`3oool2000000050?ooo`000000oooo0?ooo`3Vi^H00P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003Vi^H0i^KV00T0i^KV203oool200000080i^KV5`3oool010000000oooo0?ooo`00000C0?oo
o`030000003Vi^H0oooo00<0oooo00<000000?ooo`3oool03@3oool00`3Vi^H000000>KViP050>KV
iP<0oooo00<000000?ooo`3oool02`3oool00`000000i^KV0>KViP030>KViP030000003Vi^H0oooo
00H0oooo00<000000?ooo`3Vi^H0103Vi^H00`3oool000000?ooo`0T0?ooo`030000003Vi^H0oooo
00<0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`080?ooo`060000003oool0oooo0?ooo`000000oooo0P0000020?ooo`040>KViP3oool0
oooo000001@0oooo00<000000>KViP3Vi^H02@3Vi^H80?ooo`8000000P3Vi^HG0?ooo`040000003o
ool0oooo000001<0oooo00<000000>KViP3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030>KV
iP000000i^KV00D0i^KV0`3oool00`000000oooo0?ooo`0;0?ooo`030000003Vi^H0i^KV00<0i^KV
00<000000>KViP3oool01P3oool00`000000oooo0>KViP040>KViP030?ooo`000000oooo02@0oooo
00<000000>KViP3oool00`3oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000P3oool200000080oooo00@0
i^KV0?ooo`3oool00000503oool00`000000i^KV0>KViP090>KViPP0oooo00@0i^KV0000003Vi^H0
i^KV5`3oool010000000oooo0?ooo`00000C0?ooo`030000003Vi^H0oooo00<0oooo00<000000?oo
o`3oool03@3oool00`3Vi^H000000>KViP050>KViP<0oooo00<000000?ooo`3oool02`3oool00`00
0000i^KV0>KViP030>KViP030000003Vi^H0oooo00H0oooo00<000000?ooo`3Vi^H0103Vi^H00`3o
ool000000?ooo`0T0?ooo`030000003Vi^H0oooo00<0oooo00<0i^KV0?ooo`3oool00`3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool0i^KV0P3oool00`000000oooo0?ooo`0B0?ooo`030000003Vi^H0i^KV
00T0i^KV203oool0103Vi^H000000>KViP3Vi^HG0?ooo`040000003oool0oooo00000180oooo00<0
00000>KViP3Vi^H01@3oool00`000000oooo0?ooo`0<0?ooo`030>KViP000000i^KV00D0i^KV0`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003Vi^H0i^KV00<0i^KV00<000000>KViP3oool01@3o
ool00`000000oooo0?ooo`050>KViP80oooo00<000000?ooo`3oool08P3oool00`000000i^KV0?oo
o`030?ooo`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool00280oooo0P00000:
0?ooo`030000003oool0000000H0oooo00@0i^KV0?ooo`3oool00000503oool00`000000i^KV0>KV
iP090>KViPP0oooo0P3Vi^H00`000000i^KV0?ooo`0F0?ooo`040000003oool0oooo00000180oooo
00<000000>KViP3Vi^H01@3oool00`000000oooo0?ooo`0<0?ooo`030>KViP000000i^KV00D0i^KV
0`3oool00`000000oooo0?ooo`0;0?ooo`030000003Vi^H0i^KV00@0i^KV00<000000?ooo`3oool0
0`3oool200000080oooo1@3Vi^H20?ooo`030000003oool0oooo0280oooo00<000000>KViP3oool0
0`3oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`0000001P3oool0103Vi^H0oooo0?ooo`00000D0?ooo`030000
003Vi^H0i^KV00T0i^KV203oool20>KViP030000003Vi^H0oooo01H0oooo00@000000?ooo`3oool0
00004P3oool00`000000i^KV0>KViP050?ooo`030000003oool0oooo00`0oooo00<0i^KV0000003V
i^H01@3Vi^H30?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3Vi^H01@3Vi^H00`000000
oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`D0i^KV0P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003Vi^H0i^KV00@0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`090?ooo`8000001`3oool0103Vi^H0oooo0?ooo`00000D0?oo
o`030000003Vi^H0i^KV00T0i^KV203oool20>KViP030000003Vi^H0oooo01H0oooo00@000000?oo
o`3oool000004P3oool00`000000i^KV0>KViP050?ooo`030000003oool0oooo00`0oooo00<00000
0>KViP3Vi^H01@3Vi^H40?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3Vi^H01@3Vi^H0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`D0i^KV0P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003Vi^H0i^KV00@0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool2000000X0oooo0P0000070?ooo`040>KViP3oool0oooo000001@0oooo00<0
00000>KViP3Vi^H02@3Vi^H80?ooo`80i^KV00<000000>KViP3oool05P3oool010000000oooo0?oo
o`00000B0?ooo`030000003Vi^H0i^KV00D0oooo00<000000?ooo`3oool0303oool00`000000i^KV
0>KViP050>KViP@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0>KViP050>KViP800000
103oool010000000oooo0?ooo`3oool50>KViP80oooo00<000000?ooo`3oool08@3oool00`000000
i^KV0>KViP040?ooo`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool04P3oool01@3Vi^H0oooo0?ooo`3oool0000001<0oooo00<000000>KViP3V
i^H02@3Vi^H80?ooo`<0i^KV00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00000B0?oo
o`030000003Vi^H0i^KV00D0oooo00<000000?ooo`3oool0303oool00`000000i^KV0>KViP050>KV
iP@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0>KViP060>KViP030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo1@3Vi^H20?ooo`030000003oool0oooo0240oooo00<00000
0>KViP3Vi^H0103oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000?0?oo
o`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0180oooo00D0i^KV0?oo
o`3oool0oooo0000000C0?ooo`030000003Vi^H0i^KV00T0i^KV203oool30>KViP030000003oool0
oooo00T0oooo0P00000:0?ooo`040000003oool0oooo00000180oooo00<000000>KViP3Vi^H01@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003Vi^H0i^KV00D0i^KV103oool00`000000oooo0?oo
o`090?ooo`030000003oool0i^KV00H0i^KV00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`3oool50>KViP80oooo00<000000?ooo`3oool0803oool200000080i^KV103oool00`3Vi^H0oooo
0?ooo`030?ooo`030000003oool0oooo0100oooo000>0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0B0?ooo`050>KViP3oool0oooo0?oo
o`0000004`3oool00`000000i^KV0>KViP090>KViPP0oooo0`3Vi^H00`000000oooo0?ooo`090?oo
o`8000002P3oool010000000oooo0?ooo`00000B0?ooo`030000003Vi^H0i^KV00D0oooo00<00000
0?ooo`3oool02P3oool2000000P0i^KV103oool00`000000oooo0?ooo`090?ooo`030000003oool0
i^KV00H0i^KV00<0oooo0000003oool00P3oool010000000oooo0?ooo`3oool50>KViP80oooo00<0
00000?ooo`3oool0803oool010000000oooo0>KViP3Vi^H40?ooo`030>KViP3oool0oooo00<0oooo
00<000000?ooo`3oool0403oool000h0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`<000004P3oool01@3Vi^H0oooo0?ooo`3oool0000001<0oooo00<000000>KV
iP3Vi^H02@3Vi^H80?ooo`<0i^KV00<000000?ooo`3oool02@3oool2000000T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003Vi^H0i^KV00D0oooo00<000000?oo
o`3oool02P3oool2000000P0i^KV103oool00`000000oooo0?ooo`090?ooo`030000003oool0i^KV
00H0i^KV00<0oooo0000003oool00P3oool010000000oooo0?ooo`3oool50>KViP80oooo00<00000
0?ooo`3oool0803oool010000000oooo0>KViP3Vi^H40?ooo`030>KViP3oool0oooo0080oooo0P00
000B0?ooo`003P3oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`000000oooo0?oo
o`0B0?ooo`050>KViP3oool0oooo0?ooo`0000004`3oool00`000000i^KV0>KViP090>KViPP0oooo
103Vi^H00`000000oooo0?ooo`080?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00h0oooo00@000000?ooo`3Vi^H0i^KV1@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0i^KV103oool00`000000oooo0?ooo`090?ooo`030000003oool0i^KV00H0
i^KV00<0oooo0000003oool00P3oool010000000oooo0?ooo`3oool50>KViP<0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`020>KViP@0oooo00<0i^KV0?ooo`3oool00`3oool00`00
0000oooo0?ooo`0@0?ooo`003P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool04P3oool01@3Vi^H0oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3Vi^H02P3Vi^H80?ooo`@0i^KV00<000000?ooo`3oool0203oool00`000000oooo0000
00060?ooo`8000001@3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0i^KV0>KViPD0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080>KViP@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070>KViP050?ooo`000000oooo0?ooo`000000103oool50>KViP<0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
i^KV103oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000?0?ooo`800000
2P3oool2000000D0oooo0P00000C0?ooo`030>KViP3oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0>KViP0:0>KViPP0oooo103Vi^H00`000000oooo0?ooo`080?ooo`030000
003oool0000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`040000
003oool0i^KV0>KViPD0oooo00<000000?ooo`3oool01`3oool2000000<0oooo203Vi^H50?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3Vi^H20?ooo`030000003oool0000000@0
oooo1@3Vi^H30?ooo`030000003oool0oooo0140oooo0P0000000`3oool000000?ooo`080?ooo`03
0000003oool0oooo0080i^KV103oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo0180oooo00<0i^KV0?ooo`3oool00P3oool00`000000oooo
0?ooo`0=0?ooo`040000003oool000000?ooo`/0i^KV203oool40>KViP030000003oool0oooo00P0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0
oooo00@000000?ooo`3Vi^H0i^KV1@3oool00`000000oooo0?ooo`070?ooo`8000000`3oool80>KV
iPD0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070>KViP80oooo0P0000050?oo
o`D0i^KV0`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool000000?ooo`8000002@3oool0
0`000000oooo0?ooo`020>KViP@0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`0B0?ooo`030>KViP3oool0oooo0080oooo00<000000?oo
o`3oool03@3oool200000080oooo2`3Vi^H80?ooo`@0i^KV00<000000?ooo`3oool0203oool00`00
0000oooo000000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool01000
0000oooo0>KViP3Vi^H50?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool8
0>KViPD0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070>KViP80oooo0P000005
0?ooo`D0i^KV0`3oool00`000000oooo0?ooo`0?0?ooo`<000000P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080i^KV103oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0
oooo0100oooo000R0?ooo`8000004`3oool00`3Vi^H0oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`/0i^KV203oool40>KViP030?ooo`000000
oooo00L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3Vi^H0i^KV1P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00`3oool80>KViPD0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070>KViPT0oooo1@3Vi^H30?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool0oooo0P3V
i^H40?ooo`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool04P3oool00`3Vi^H0oooo0?ooo`030?ooo`040000003oool00000000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`/0i^KV203oool40>KViP030?ooo`00
0000oooo00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool03@3oool010000000oooo0>KViP3Vi^H60?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`040?ooo`P0i^KV1P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0i^KV2@3oool50>KViP<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`3oool20>KViP@0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`0B0?ooo`030>KViP3oool0oooo00<0oooo10000003
0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`/0i^KV203oool40>KViP030?ooo`000000
oooo00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`020>KViPL0oooo00<000000?ooo`3oool00P00
00000`3oool000000?ooo`050?ooo`P0i^KV1P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0i^KV2@3oool50>KViP<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool0oooo0P3Vi^H40?ooo`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool04P3oool00`3Vi^H0oooo0?ooo`060?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo2`3Vi^H80?ooo`@0
i^KV0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3Vi^H70?oo
o`030000003oool000000080oooo0P0000060?ooo`P0i^KV1P3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo0?ooo`L0i^KV2@3oool50>KViP@0oooo00<000000?ooo`3oool0103oool2
000000<0oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo0?ooo`80i^KV103oool00`3Vi^H0oooo0?ooo`030?ooo`030000003oool0oooo0100oooo
000R0?ooo`8000004`3oool00`3Vi^H0oooo0?ooo`070?ooo`<000000P3oool010000000oooo0?oo
o`0000060?ooo`/0i^KV203oool40>KViP80oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`040000003oool00000000000X0oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`3oool20>KViPP0oooo00<000000?ooo`3oool02@3oool80>KViPH0oooo00<000000?oo
o`3oool01@3oool010000000oooo0?ooo`3oool70>KViPT0oooo1@3Vi^H50?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`00000=0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool20>KViP@0oooo00<0i^KV0?ooo`3oool00`3oool00`000000oooo0?ooo`0@
0?ooo`006P3oool5000000<0oooo00<000000?ooo`3oool04P3oool00`3Vi^H0oooo0?ooo`0=0?oo
o`<000001P3oool;0>KViPP0oooo103Vi^H30?ooo`8000000P3oool2000000L0oooo0P00000<0?oo
o`8000002@3oool00`000000oooo0?ooo`020?ooo`80i^KV503oool80>KViPL0oooo0`0000020?oo
o`800000103oool70>KViPT0oooo1@3Vi^H60?ooo`@000004`3oool5000000D0oooo0P3Vi^H40?oo
o`030>KViP3oool0oooo00<0oooo00<000000?ooo`3oool0403oool001`0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0B0?ooo`030>KViP3oool0oooo01H0oooo2`3Vi^H80?ooo`@0
i^KV1@3oool2000001T0oooo2@0000050?ooo`80i^KV503oool80>KViPT0oooo0`0000060?ooo`L0
i^KV2@3oool50>KViRL0oooo0P3Vi^H40?ooo`030>KViP3oool0oooo00<0oooo00<000000?ooo`3o
ool0403oool001`0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool0
303oool00`3Vi^H0oooo0?ooo`0C0?ooo`030000003oool0oooo00/0i^KV203oool40>KViP/0oooo
00<000000?ooo`3oool0803oool20>KViP030?ooo`000000oooo0140oooo203Vi^H:0?ooo`030000
003oool0oooo00D0oooo1`3Vi^H90?ooo`D0i^KV203oool00`000000oooo0?ooo`0L0?ooo`80i^KV
103oool00`3Vi^H000000?ooo`020?ooo`8000004P3oool001`0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool001`0oooo00<000000?ooo`3oool00`3oooo/00000180oooo000K0?ooo`800000o`3oool40?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {85.375, 0}} -> {-53.7853, -0.202584, 1.33829, \
0.0148699}}]
}, Open  ]],

Cell[TextData[{
  "Abbildung 2.42 zeigt die Posteriorwahrscheinlichkeit ",
  StyleBox["P(F | x)",
    FontSlant->"Italic"],
  " f\[UDoubleDot]r diese Sequenz ",
  StyleBox["x",
    FontSlant->"Italic"],
  ".\n"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{507, 651},
WindowMargins->{{36, Automatic}, {Automatic, -28}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 553, 21, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2332, 76, 179, 6, 97, "Subtitle"],
Cell[2514, 84, 976, 26, 185, "Text"],
Cell[3493, 112, 107, 2, 30, "Input"],
Cell[3603, 116, 104, 2, 30, "Input"],
Cell[3710, 120, 270, 6, 90, "Input"],
Cell[3983, 128, 609, 11, 210, "Input"],
Cell[4595, 141, 212, 5, 71, "Text"],
Cell[4810, 148, 80, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[4915, 154, 111, 2, 30, "Input"],
Cell[5029, 158, 198, 3, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5264, 166, 143, 4, 70, "Input"],
Cell[5410, 172, 101, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5548, 179, 111, 2, 30, "Input"],
Cell[5662, 183, 198, 3, 67, "Output"]
}, Open  ]],
Cell[5875, 189, 177, 4, 50, "Input"],
Cell[6055, 195, 103, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[6183, 201, 82, 2, 30, "Input"],
Cell[6268, 205, 37, 1, 29, "Output"]
}, Open  ]],
Cell[6320, 209, 323, 10, 71, "Text"],
Cell[6646, 221, 79, 1, 30, "Input"],
Cell[6728, 224, 462, 8, 190, "Input"],
Cell[7193, 234, 557, 18, 111, "Text"],

Cell[CellGroupData[{
Cell[7775, 256, 147, 3, 70, "Input"],
Cell[7925, 261, 43, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8005, 267, 147, 3, 70, "Input"],
Cell[8155, 272, 66, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8258, 278, 147, 3, 70, "Input"],
Cell[8408, 283, 83, 1, 29, "Output"]
}, Open  ]],
Cell[8506, 287, 162, 7, 33, "Text"],

Cell[CellGroupData[{
Cell[8693, 298, 122, 3, 50, "Input"],
Cell[8818, 303, 87, 1, 29, "Output"]
}, Open  ]],
Cell[8920, 307, 407, 12, 71, "Text"],

Cell[CellGroupData[{
Cell[9352, 323, 69, 1, 30, "Input"],
Cell[9424, 326, 58, 1, 29, "Output"]
}, Open  ]],
Cell[9497, 330, 1308, 28, 299, "Text"],
Cell[10808, 360, 554, 10, 210, "Input"],
Cell[11365, 372, 160, 6, 33, "Text"],
Cell[11528, 380, 82, 1, 30, "Input"],
Cell[11613, 383, 485, 9, 190, "Input"],
Cell[12101, 394, 612, 18, 91, "Text"],

Cell[CellGroupData[{
Cell[12738, 416, 123, 3, 50, "Input"],
Cell[12864, 421, 119, 2, 29, "Output"]
}, Open  ]],
Cell[12998, 426, 506, 18, 71, "Text"],

Cell[CellGroupData[{
Cell[13529, 448, 253, 6, 110, "Input"],
Cell[13785, 456, 58, 1, 29, "Output"]
}, Open  ]],
Cell[13858, 460, 721, 20, 128, "Text"],
Cell[14582, 482, 294, 5, 130, "Input"],
Cell[14879, 489, 201, 5, 52, "Text"],
Cell[15083, 496, 92, 1, 30, "Input"],
Cell[15178, 499, 501, 11, 109, "Text"],
Cell[15682, 512, 103, 2, 30, "Input"],
Cell[15788, 516, 165, 3, 50, "Input"],
Cell[15956, 521, 126, 3, 70, "Input"],
Cell[16085, 526, 164, 3, 90, "Input"],
Cell[16252, 531, 135, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[16412, 538, 147, 2, 50, "Input"],
Cell[16562, 542, 33710, 948, 152, 8455, 632, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[50287, 1493, 689, 15, 167, "Text"],
Cell[50979, 1510, 453, 8, 190, "Input"],
Cell[51435, 1520, 183, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[51643, 1529, 59, 1, 30, "Input"],
Cell[51705, 1532, 37, 1, 29, "Output"]
}, Open  ]],
Cell[51757, 1536, 263, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[52045, 1549, 75, 1, 30, "Input"],
Cell[52123, 1552, 1681, 22, 314, "Output"]
}, Open  ]],
Cell[53819, 1577, 576, 14, 129, "Text"],
Cell[54398, 1593, 428, 8, 170, "Input"],

Cell[CellGroupData[{
Cell[54851, 1605, 124, 3, 50, "Input"],
Cell[54978, 1610, 1018, 13, 314, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56033, 1628, 131, 2, 38, "Subsection"],
Cell[56167, 1632, 107, 2, 30, "Input"],
Cell[56277, 1636, 104, 2, 30, "Input"],
Cell[56384, 1640, 270, 6, 90, "Input"],
Cell[56657, 1648, 609, 11, 210, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57303, 1664, 132, 5, 38, "Subsection"],

Cell[CellGroupData[{
Cell[57460, 1673, 82, 2, 30, "Input"],
Cell[57545, 1677, 37, 1, 29, "Output"]
}, Open  ]],
Cell[57597, 1681, 113, 2, 30, "Input"],
Cell[57713, 1685, 496, 9, 190, "Input"],

Cell[CellGroupData[{
Cell[58234, 1698, 135, 3, 30, "Input"],
Cell[58372, 1703, 43, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58452, 1709, 135, 3, 50, "Input"],
Cell[58590, 1714, 66, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58693, 1720, 135, 3, 50, "Input"],
Cell[58831, 1725, 83, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58951, 1731, 156, 4, 50, "Input"],
Cell[59110, 1737, 90, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59237, 1743, 103, 2, 30, "Input"],
Cell[59343, 1747, 58, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[59450, 1754, 133, 5, 38, "Subsection"],
Cell[59586, 1761, 588, 11, 210, "Input"],
Cell[60177, 1774, 116, 2, 30, "Input"],
Cell[60296, 1778, 519, 10, 190, "Input"],

Cell[CellGroupData[{
Cell[60840, 1792, 136, 3, 50, "Input"],
Cell[60979, 1797, 51, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61067, 1803, 157, 4, 50, "Input"],
Cell[61227, 1809, 120, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61384, 1816, 287, 7, 110, "Input"],
Cell[61674, 1825, 58, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[61781, 1832, 77, 1, 38, "Subsection"],
Cell[61861, 1835, 328, 6, 130, "Input"],
Cell[62192, 1843, 128, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[62345, 1850, 170, 3, 50, "Input"],
Cell[62518, 1855, 37046, 1065, 95, 9689, 722, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[99613, 2926, 84, 1, 38, "Subsection"],

Cell[CellGroupData[{
Cell[99722, 2931, 190, 4, 50, "Input"],
Cell[99915, 2937, 37046, 1065, 95, 9689, 722, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[136976, 4005, 140, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[137141, 4012, 140, 3, 70, "Input"],
Cell[137284, 4017, 125, 2, 48, "Output"]
}, Open  ]],
Cell[137424, 4022, 198, 4, 90, "Input"],
Cell[137625, 4028, 194, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[137844, 4036, 156, 3, 50, "Input"],
Cell[138003, 4041, 50221, 1515, 95, 15051, 1076, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[188239, 5559, 271, 10, 71, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

